# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/logicmodule_messages.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_messages_pb2 as protos_dot_common__messages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!protos/logicmodule_messages.proto\x12\x12protos.logicmodule\x1a\x1cprotos/common_messages.proto\"2\n\x18NewAccountNoAdminRequest\x12\x16\n\x0eyamlNewAccount\x18\x01 \x01(\t\"p\n\x11NewAccountRequest\x12\x0f\n\x07\x61\x64minID\x18\x01 \x01(\t\x12\x32\n\x0f\x61\x64mincredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x16\n\x0eyamlNewAccount\x18\x03 \x01(\t\"Y\n\x12NewAccountResponse\x12\x14\n\x0cnewAccountID\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"7\n\x15PublishAddressRequest\x12\x10\n\x08hostname\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\"*\n\x13GetAccountIDRequest\x12\x13\n\x0b\x61\x63\x63ountName\x18\x01 \x01(\t\"[\n\x14GetAccountIDResponse\x12\x14\n\x0cnewAccountID\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"f\n\x15\x41utoRegisterSLRequest\x12\x19\n\x11storageLocationID\x18\x01 \x01(\t\x12\x0e\n\x06\x64sName\x18\x02 \x01(\t\x12\x12\n\ndsHostname\x18\x03 \x01(\t\x12\x0e\n\x06\x64sPort\x18\x04 \x01(\x05\"\x8f\x01\n\x15\x41utoRegisterEERequest\x12\x1e\n\x16\x65xecutionEnvironmentID\x18\x01 \x01(\t\x12\x0e\n\x06\x65\x65Name\x18\x02 \x01(\t\x12\x12\n\neeHostname\x18\x03 \x01(\t\x12\x0e\n\x06\x65\x65Port\x18\x04 \x01(\x05\x12\"\n\x04lang\x18\x05 \x01(\x0e\x32\x14.protos.common.Langs\"b\n\x16\x41utoRegisterEEResponse\x12\x19\n\x11storageLocationID\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"=\n UnregisterStorageLocationRequest\x12\x19\n\x11storageLocationID\x18\x01 \x01(\t\"G\n%UnregisterExecutionEnvironmentRequest\x12\x1e\n\x16\x65xecutionEnvironmentID\x18\x01 \x01(\t\"k\n\x19PerformSetAccountsRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x0c\n\x04yaml\x18\x03 \x01(\t\"_\n\x1aPerformSetAccountsResponse\x12\x12\n\nresultYaml\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"m\n\x1bPerformSetOperationsRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x0c\n\x04yaml\x18\x03 \x01(\t\"a\n\x1cPerformSetOperationsResponse\x12\x12\n\nresultYaml\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"\\\n\x15GetAccountListRequest\x12\x0f\n\x07\x61\x64minID\x18\x01 \x01(\t\x12\x32\n\x0f\x61\x64mincredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\"[\n\x16GetAccountListResponse\x12\x12\n\naccountIDs\x18\x01 \x03(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"\xbf\x01\n\x11NewSessionRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x13\n\x0b\x63ontractIDs\x18\x03 \x03(\t\x12\x12\n\ndataSetIDs\x18\x04 \x03(\t\x12\x14\n\x0cstoreDataSet\x18\x05 \x01(\t\x12)\n\x0bsessionLang\x18\x06 \x01(\x0e\x32\x14.protos.common.Langs\"X\n\x12NewSessionResponse\x12\x13\n\x0bsessionInfo\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"1\n\x1cGetInfoOfSessionForDSRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\"\x83\x01\n\x1dGetInfoOfSessionForDSResponse\x12\x11\n\tdataSetID\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x02 \x01(\x03\x12\x12\n\ndataSetIDs\x18\x03 \x03(\t\x12-\n\x07\x65xcInfo\x18\x04 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"q\n\x13NewNamespaceRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x18\n\x10newNamespaceYaml\x18\x03 \x01(\t\"Z\n\x14NewNamespaceResponse\x12\x13\n\x0bnamespaceID\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"X\n\x14GetNamespacesRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\"Z\n\x15GetNamespacesResponse\x12\x12\n\nnamespaces\x18\x01 \x03(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"q\n\x16RemoveNamespaceRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x15\n\rnamespaceName\x18\x03 \x01(\t\"p\n\x15GetNamespaceIDRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x15\n\rnamespaceName\x18\x03 \x01(\t\"\\\n\x16GetNamespaceIDResponse\x12\x13\n\x0bnamespaceID\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"r\n\x17GetNamespaceLangRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x15\n\rnamespaceName\x18\x03 \x01(\t\"q\n\x18GetNamespaceLangResponse\x12&\n\x08language\x18\x01 \x01(\x0e\x32\x14.protos.common.Langs\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"@\n\x19GetObjectDataSetIDRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12\x10\n\x08objectID\x18\x02 \x01(\t\"^\n\x1aGetObjectDataSetIDResponse\x12\x11\n\tdataSetID\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"\x98\x01\n\x16ImportInterfaceRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x13\n\x0bnamespaceID\x18\x03 \x01(\t\x12\x12\n\ncontractID\x18\x04 \x01(\t\x12\x13\n\x0binterfaceID\x18\x05 \x01(\t\"\x82\x01\n\x15ImportContractRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x13\n\x0bnamespaceID\x18\x03 \x01(\t\x12\x12\n\ncontractID\x18\x04 \x01(\t\"j\n\x11NewDataSetRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x13\n\x0b\x64\x61taSetYaml\x18\x03 \x01(\t\"V\n\x12NewDataSetResponse\x12\x11\n\tdataSetID\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"m\n\x14RemoveDataSetRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x13\n\x0b\x64\x61taSetName\x18\x03 \x01(\t\"l\n\x13GetDataSetIDRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x13\n\x0b\x64\x61taSetName\x18\x03 \x01(\t\"X\n\x14GetDataSetIDResponse\x12\x11\n\tdataSetID\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"\\\n\x18GetPublicDataSetsRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\"\\\n\x19GetPublicDataSetsResponse\x12\x10\n\x08\x64\x61taSets\x18\x01 \x03(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"]\n\x19GetAccountDataSetsRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\"]\n\x1aGetAccountDataSetsResponse\x12\x10\n\x08\x64\x61taSets\x18\x01 \x03(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"0\n\x1b\x43heckDataSetIsPublicRequest\x12\x11\n\tdataSetID\x18\x01 \x01(\t\"_\n\x1c\x43heckDataSetIsPublicResponse\x12\x10\n\x08isPublic\x18\x01 \x01(\x08\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"\xf7\x01\n\x0fNewClassRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12&\n\x08language\x18\x03 \x01(\x0e\x32\x14.protos.common.Langs\x12G\n\nnewClasses\x18\x04 \x03(\x0b\x32\x33.protos.logicmodule.NewClassRequest.NewClassesEntry\x1a\x31\n\x0fNewClassesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbe\x01\n\x10NewClassResponse\x12H\n\nnewClasses\x18\x01 \x03(\x0b\x32\x34.protos.logicmodule.NewClassResponse.NewClassesEntry\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\x1a\x31\n\x0fNewClassesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"~\n\x12RemoveClassRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x13\n\x0bnamespaceID\x18\x03 \x01(\t\x12\x11\n\tclassName\x18\x04 \x01(\t\"\xa5\x01\n\x16RemoveOperationRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x13\n\x0bnamespaceID\x18\x03 \x01(\t\x12\x11\n\tclassName\x18\x04 \x01(\t\x12!\n\x19operationNameAndSignature\x18\x05 \x01(\t\"\xa1\x01\n\x1bRemoveImplementationRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x13\n\x0bnamespaceID\x18\x03 \x01(\t\x12\x11\n\tclassName\x18\x04 \x01(\t\x12\x18\n\x10implementationID\x18\x05 \x01(\t\"\xa4\x01\n\x15GetOperationIDRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x13\n\x0bnamespaceID\x18\x03 \x01(\t\x12\x11\n\tclassName\x18\x04 \x01(\t\x12!\n\x19operationNameAndSignature\x18\x05 \x01(\t\"\\\n\x16GetOperationIDResponse\x12\x13\n\x0boperationID\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"\x96\x01\n\x14GetPropertyIDRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x13\n\x0bnamespaceID\x18\x03 \x01(\t\x12\x11\n\tclassName\x18\x04 \x01(\t\x12\x14\n\x0cpropertyName\x18\x05 \x01(\t\"Z\n\x15GetPropertyIDResponse\x12\x12\n\npropertyID\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"}\n\x11GetClassIDRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x13\n\x0bnamespaceID\x18\x03 \x01(\t\x12\x11\n\tclassName\x18\x04 \x01(\t\"T\n\x12GetClassIDResponse\x12\x0f\n\x07\x63lassID\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"\x7f\n\x13GetClassInfoRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x13\n\x0bnamespaceID\x18\x03 \x01(\t\x12\x11\n\tclassName\x18\x04 \x01(\t\"\\\n\x14GetClassInfoResponse\x12\x15\n\rmetaClassYaml\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"{\n\"GetInfoOfClassesInNamespaceRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x13\n\x0bnamespaceID\x18\x03 \x01(\t\"\xe7\x01\n#GetInfoOfClassesInNamespaceResponse\x12]\n\x0b\x63lassesInfo\x18\x01 \x03(\x0b\x32H.protos.logicmodule.GetInfoOfClassesInNamespaceResponse.ClassesInfoEntry\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\x1a\x32\n\x10\x43lassesInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x81\x01\n(GetImportedClassesInfoInNamespaceRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x13\n\x0bnamespaceID\x18\x03 \x01(\t\"\xff\x01\n)GetImportedClassesInfoInNamespaceResponse\x12k\n\x0fimportedClasses\x18\x01 \x03(\x0b\x32R.protos.logicmodule.GetImportedClassesInfoInNamespaceResponse.ImportedClassesEntry\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\x1a\x36\n\x14ImportedClassesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x87\x01\n\x1bGetClassIDFromImportRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x13\n\x0bnamespaceID\x18\x03 \x01(\t\x12\x11\n\tclassName\x18\x04 \x01(\t\"^\n\x1cGetClassIDFromImportResponse\x12\x0f\n\x07\x63lassID\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"o\n\x12NewContractRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x17\n\x0fnewContractYaml\x18\x03 \x01(\t\"X\n\x13NewContractResponse\x12\x12\n\ncontractID\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"w\n\x1fRegisterToPublicContractRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x12\n\ncontractID\x18\x03 \x01(\t\"\x83\x01\n*RegisterToPublicContractOfNamespaceRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x13\n\x0bnamespaceID\x18\x03 \x01(\t\"p\n+RegisterToPublicContractOfNamespaceResponse\x12\x12\n\ncontractID\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"f\n GetContractIDsOfApplicantRequest\x12\x13\n\x0b\x61pplicantID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\"\xdd\x01\n!GetContractIDsOfApplicantResponse\x12W\n\tcontracts\x18\x01 \x03(\x0b\x32\x44.protos.logicmodule.GetContractIDsOfApplicantResponse.ContractsEntry\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\x1a\x30\n\x0e\x43ontractsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x83\x01\n\x1fGetContractIDsOfProviderRequest\x12\x12\n\nproviderID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x1d\n\x15namespaceIDOfProvider\x18\x03 \x01(\t\"\xdb\x01\n GetContractIDsOfProviderResponse\x12V\n\tcontracts\x18\x01 \x03(\x0b\x32\x43.protos.logicmodule.GetContractIDsOfProviderResponse.ContractsEntry\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\x1a\x30\n\x0e\x43ontractsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8b\x01\n&GetContractsOfApplicantWithProvRequest\x12\x13\n\x0b\x61pplicantID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x1d\n\x15namespaceIDOfProvider\x18\x03 \x01(\t\"\xe9\x01\n\'GetContractsOfApplicantWithProvResponse\x12]\n\tcontracts\x18\x01 \x03(\x0b\x32J.protos.logicmodule.GetContractsOfApplicantWithProvResponse.ContractsEntry\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\x1a\x30\n\x0e\x43ontractsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"t\n\x16NewDataContractRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x18\n\x10\x64\x61taContractYaml\x18\x03 \x01(\t\"`\n\x17NewDataContractResponse\x12\x16\n\x0e\x64\x61taContractID\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"\x7f\n#RegisterToPublicDataContractRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x16\n\x0e\x64\x61taContractID\x18\x03 \x01(\t\"j\n$GetDataContractIDsOfApplicantRequest\x12\x13\n\x0b\x61pplicantID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\"\xf1\x01\n%GetDataContractIDsOfApplicantResponse\x12\x63\n\rdatacontracts\x18\x01 \x03(\x0b\x32L.protos.logicmodule.GetDataContractIDsOfApplicantResponse.DatacontractsEntry\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\x1a\x34\n\x12\x44\x61tacontractsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x85\x01\n#GetDataContractIDsOfProviderRequest\x12\x12\n\nproviderID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x1b\n\x13\x64\x61taSetIDOfProvider\x18\x03 \x01(\t\"\xef\x01\n$GetDataContractIDsOfProviderResponse\x12\x62\n\rdatacontracts\x18\x01 \x03(\x0b\x32K.protos.logicmodule.GetDataContractIDsOfProviderResponse.DatacontractsEntry\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\x1a\x34\n\x12\x44\x61tacontractsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x90\x01\n-GetDataContractInfoOfApplicantWithProvRequest\x12\x13\n\x0b\x61pplicantID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x1b\n\x13\x64\x61taSetIDOfProvider\x18\x03 \x01(\t\"y\n.GetDataContractInfoOfApplicantWithProvResponse\x12\x18\n\x10\x64\x61taContractInfo\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"p\n\x13NewInterfaceRequest\x12\x13\n\x0b\x61pplicantID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x15\n\rinterfaceYaml\x18\x03 \x01(\t\"Z\n\x14NewInterfaceResponse\x12\x13\n\x0binterfaceID\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"r\n\x17GetInterfaceInfoRequest\x12\x13\n\x0b\x61pplicantID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x13\n\x0binterfaceID\x18\x03 \x01(\t\"`\n\x18GetInterfaceInfoResponse\x12\x15\n\rinterfaceYaml\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"\x86\x01\n\x16RemoveInterfaceRequest\x12\x13\n\x0b\x61pplicantID\x18\x01 \x01(\t\x12-\n\ncredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x13\n\x0bnamespaceID\x18\x03 \x01(\t\x12\x13\n\x0binterfaceID\x18\x04 \x01(\t\"O\n\x1dGetStorageLocationInfoRequest\x12\x19\n\x11storageLocationID\x18\x01 \x01(\t\x12\x13\n\x0b\x66romBackend\x18\x02 \x01(\x08\"\x90\x01\n\x1eGetStorageLocationInfoResponse\x12?\n\x13storageLocationInfo\x18\x01 \x01(\x0b\x32\".protos.common.StorageLocationInfo\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"L\n\"GetExecutionEnvironmentInfoRequest\x12\x11\n\texecEnvID\x18\x01 \x01(\t\x12\x13\n\x0b\x66romBackend\x18\x02 \x01(\x08\"\x9f\x01\n#GetExecutionEnvironmentInfoResponse\x12I\n\x18\x65xecutionEnvironmentInfo\x18\x01 \x01(\x0b\x32\'.protos.common.ExecutionEnvironmentInfo\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"Z\n\x15GetDataClayIDResponse\x12\x12\n\ndataClayID\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"A\n\x1fRegisterExternalDataClayRequest\x12\x10\n\x08hostname\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\"\xb1\x01\n0RegisterExternalDataClayOverrideAuthorityRequest\x12\x16\n\x0e\x61\x64minAccountID\x18\x01 \x01(\t\x12\x32\n\x0f\x61\x64minCredential\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x10\n\x08hostname\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\x05\x12\x11\n\tauthority\x18\x05 \x01(\t\"h\n RegisterExternalDataClayResponse\x12\x15\n\rextDataClayID\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"d\n+NotifyRegistrationOfExternalDataClayRequest\x12\x15\n\rextDataClayID\x18\x01 \x01(\t\x12\x10\n\x08hostname\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\x05\"t\n,NotifyRegistrationOfExternalDataClayResponse\x12\x15\n\rextDataClayID\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\":\n\x1cGetExternalDataclayIDRequest\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\"e\n\x1dGetExternalDataclayIDResponse\x12\x15\n\rextDataClayID\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"2\n\x19GetExtDataClayInfoRequest\x12\x15\n\rextDataClayID\x18\x01 \x01(\t\"\x85\x01\n\x1aGetExtDataClayInfoResponse\x12\x38\n\x0f\x65xtDataClayInfo\x18\x01 \x01(\x0b\x32\x1f.protos.common.DataClayInstance\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"a\n\x1aRegisterObjectForGCRequest\x12\x30\n\x07regInfo\x18\x01 \x01(\x0b\x32\x1f.protos.common.RegistrationInfo\x12\x11\n\tbackendID\x18\x02 \x01(\t\"\x82\x01\n\x16RegisterObjectsRequest\x12\x31\n\x08regInfos\x18\x01 \x03(\x0b\x32\x1f.protos.common.RegistrationInfo\x12\x11\n\tbackendID\x18\x02 \x01(\t\x12\"\n\x04lang\x18\x03 \x01(\x0e\x32\x14.protos.common.Langs\"[\n\x17RegisterObjectsResponse\x12\x11\n\tobjectIDs\x18\x01 \x03(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"}\n&GetAllExecutionEnvironmentsInfoRequest\x12)\n\x0b\x65xecEnvLang\x18\x01 \x01(\x0e\x32\x14.protos.common.Langs\x12\x13\n\x0bgetExternal\x18\x02 \x01(\x08\x12\x13\n\x0b\x66romBackend\x18\x03 \x01(\x08\"\x8f\x02\n\'GetAllExecutionEnvironmentsInfoResponse\x12[\n\x08\x65xecEnvs\x18\x01 \x03(\x0b\x32I.protos.logicmodule.GetAllExecutionEnvironmentsInfoResponse.ExecEnvsEntry\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\x1aX\n\rExecEnvsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32\'.protos.common.ExecutionEnvironmentInfo:\x02\x38\x01\";\n\x14GetObjectInfoRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12\x10\n\x08objectID\x18\x02 \x01(\t\"l\n\x15GetObjectInfoResponse\x12\x11\n\tclassname\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12-\n\x07\x65xcInfo\x18\x03 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"=\n\x19GetObjectFromAliasRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12\r\n\x05\x61lias\x18\x02 \x01(\t\"|\n\x1aGetObjectFromAliasResponse\x12\x10\n\x08objectID\x18\x01 \x01(\t\x12\x0f\n\x07\x63lassID\x18\x02 \x01(\t\x12\x0c\n\x04hint\x18\x03 \x01(\t\x12-\n\x07\x65xcInfo\x18\x04 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"=\n\x0f\x41\x64\x64\x41liasRequest\x12\x1b\n\x13objectIDToHaveAlias\x18\x01 \x01(\t\x12\r\n\x05\x61lias\x18\x02 \x01(\t\"6\n\x12\x44\x65leteAliasRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12\r\n\x05\x61lias\x18\x02 \x01(\t\"V\n\x13\x44\x65leteAliasResponse\x12\x10\n\x08objectID\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"<\n)GetObjectsMetaDataInfoOfClassForNMRequest\x12\x0f\n\x07\x63lassID\x18\x01 \x01(\t\"\x8c\x02\n*GetObjectsMetaDataInfoOfClassForNMResponse\x12`\n\tmdataInfo\x18\x01 \x03(\x0b\x32M.protos.logicmodule.GetObjectsMetaDataInfoOfClassForNMResponse.MdataInfoEntry\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\x1aM\n\x0eMdataInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.protos.common.MetaDataInfo:\x02\x38\x01\"M\n\x13SetDataSetIDRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12\x10\n\x08objectID\x18\x02 \x01(\t\x12\x11\n\tdatasetID\x18\x03 \x01(\t\"N\n\'SetDataSetIDFromGarbageCollectorRequest\x12\x10\n\x08objectID\x18\x01 \x01(\t\x12\x11\n\tdatasetID\x18\x02 \x01(\t\"x\n\x11MoveObjectRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12\x10\n\x08objectID\x18\x02 \x01(\t\x12\x14\n\x0csrcBackendID\x18\x03 \x01(\t\x12\x15\n\rdestBackendID\x18\x04 \x01(\t\x12\x11\n\trecursive\x18\x05 \x01(\x08\"V\n\x12MoveObjectResponse\x12\x11\n\tobjectIDs\x18\x01 \x03(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"?\n\x18SetObjectReadOnlyRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12\x10\n\x08objectID\x18\x02 \x01(\t\"@\n\x19SetObjectReadWriteRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12\x10\n\x08objectID\x18\x02 \x01(\t\">\n\x17GetMetadataByOIDRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12\x10\n\x08objectID\x18\x02 \x01(\t\"v\n\x18GetMetadataByOIDResponse\x12+\n\x06mdInfo\x18\x01 \x01(\x0b\x32\x1b.protos.common.MetaDataInfo\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"0\n\x1cGetMetadataByOIDForDSRequest\x12\x10\n\x08objectID\x18\x01 \x01(\t\"{\n\x1dGetMetadataByOIDForDSResponse\x12+\n\x06mdInfo\x18\x01 \x01(\x0b\x32\x1b.protos.common.MetaDataInfo\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"\xd8\x01\n\x1c\x45xecuteImplementationRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12\x13\n\x0boperationID\x18\x02 \x01(\t\x12\x18\n\x10implementationID\x18\x03 \x01(\t\x12\x12\n\ncontractID\x18\x04 \x01(\t\x12\x13\n\x0binterfaceID\x18\x05 \x01(\t\x12\x10\n\x08objectID\x18\x06 \x01(\t\x12;\n\x06params\x18\x07 \x01(\x0b\x32+.protos.common.SerializedParametersOrReturn\"\x88\x01\n\x1d\x45xecuteImplementationResponse\x12\x38\n\x03ret\x18\x01 \x01(\x0b\x32+.protos.common.SerializedParametersOrReturn\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"\xbc\x01\n\x1c\x45xecuteMethodOnTargetRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12\x10\n\x08objectID\x18\x02 \x01(\t\x12!\n\x19operationNameAndSignature\x18\x03 \x01(\t\x12;\n\x06params\x18\x04 \x01(\x0b\x32+.protos.common.SerializedParametersOrReturn\x12\x17\n\x0ftargetBackendID\x18\x05 \x01(\t\"\x88\x01\n\x1d\x45xecuteMethodOnTargetResponse\x12\x38\n\x03ret\x18\x01 \x01(\x0b\x32+.protos.common.SerializedParametersOrReturn\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"\xb8\x01\n!SynchronizeFederatedObjectRequest\x12\x15\n\rextDataClayID\x18\x01 \x01(\t\x12\x10\n\x08objectID\x18\x02 \x01(\t\x12\x18\n\x10implementationID\x18\x03 \x01(\t\x12;\n\x06params\x18\x04 \x01(\x0b\x32+.protos.common.SerializedParametersOrReturn\x12\x13\n\x0b\x61llBackends\x18\x05 \x01(\x08\"\x9a\x01\n\x0fGetStubsRequest\x12\x1a\n\x12\x61pplicantAccountID\x18\x01 \x01(\t\x12.\n\x0b\x63redentials\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12&\n\x08language\x18\x03 \x01(\x0e\x32\x14.protos.common.Langs\x12\x13\n\x0b\x63ontractIDs\x18\x04 \x03(\t\"\xaf\x01\n\x10GetStubsResponse\x12>\n\x05stubs\x18\x01 \x03(\x0b\x32/.protos.logicmodule.GetStubsResponse.StubsEntry\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\x1a,\n\nStubsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"n\n\x14GetBabelStubsRequest\x12\x11\n\taccountID\x18\x01 \x01(\t\x12.\n\x0b\x63redentials\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x13\n\x0b\x63ontractIDs\x18\x04 \x03(\t\"X\n\x15GetBabelStubsResponse\x12\x10\n\x08yamlStub\x18\x01 \x01(\x0c\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"+\n\x18GetClassNameForDSRequest\x12\x0f\n\x07\x63lassID\x18\x01 \x01(\t\"]\n\x19GetClassNameForDSResponse\x12\x11\n\tclassName\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"7\n$GetClassNameAndNamespaceForDSRequest\x12\x0f\n\x07\x63lassID\x18\x01 \x01(\t\"|\n%GetClassNameAndNamespaceForDSResponse\x12\x11\n\tclassName\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12-\n\x07\x65xcInfo\x18\x03 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"m\n\x12RegisterECARequest\x12\x1a\n\x12\x61pplicantAccountID\x18\x01 \x01(\t\x12.\n\x0b\x63redentials\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\x12\x0b\n\x03\x65\x63\x61\x18\x03 \x01(\t\"\'\n\x12\x41\x64viseEventRequest\x12\x11\n\teventYaml\x18\x01 \x01(\t\"t\n&GetContractIDOfDataClayProviderRequest\x12\x1a\n\x12\x61pplicantAccountID\x18\x01 \x01(\t\x12.\n\x0b\x63redentials\x18\x02 \x01(\x0b\x32\x19.protos.common.Credential\"l\n\'GetContractIDOfDataClayProviderResponse\x12\x12\n\ncontractID\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"(\n\x16\x41\x63tivateTracingRequest\x12\x0e\n\x06taskid\x18\x01 \x01(\x05\"(\n\x13\x43loseSessionRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\"7\n\x18UnregisterObjectsRequest\x12\x1b\n\x13objectsToUnregister\x18\x01 \x03(\t\"^\n\x1cIsPrefetchingEnabledResponse\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"1\n\x1dObjectExistsInDataClayRequest\x12\x10\n\x08objectID\x18\x01 \x01(\t\"_\n\x1eObjectExistsInDataClayResponse\x12\x0e\n\x06\x65xists\x18\x01 \x01(\x08\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"5\n\x1cGetClassesInNamespaceRequest\x12\x15\n\rnamespaceName\x18\x01 \x01(\t\"|\n\x1dGetClassesInNamespaceResponse\x12\x15\n\rnamespaceYaml\x18\x01 \x01(\t\x12\x15\n\rmetaClassYaml\x18\x02 \x03(\t\x12-\n\x07\x65xcInfo\x18\x03 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"T\n\'ImportModelsFromExternalDataClayRequest\x12\x15\n\rnamespaceName\x18\x01 \x01(\t\x12\x12\n\ndataClayID\x18\x02 \x01(\t\"-\n\x1bGetStorageLocationIDRequest\x12\x0e\n\x06slName\x18\x01 \x01(\t\"h\n\x1cGetStorageLocationIDResponse\x12\x19\n\x11storageLocationID\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"K\n)NotifyExecutionEnvironmentShutdownRequest\x12\x1e\n\x16\x65xecutionEnvironmentID\x18\x01 \x01(\t\"A\n$NotifyStorageLocationShutdownRequest\x12\x19\n\x11storageLocationID\x18\x01 \x01(\t\"A\n$ExistsActiveEnvironmentsForSLRequest\x12\x19\n\x11storageLocationID\x18\x01 \x01(\t\"f\n%ExistsActiveEnvironmentsForSLResponse\x12\x0e\n\x06\x65xists\x18\x01 \x01(\x08\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"\x91\x01\n\x0cMetadataInfo\x12\x12\n\ndataClayID\x18\x01 \x01(\t\x12\x12\n\nisReadOnly\x18\x02 \x01(\x08\x12\x11\n\tdatasetID\x18\x03 \x01(\t\x12\x13\n\x0bmetaclassID\x18\x04 \x01(\t\x12\x11\n\tlocations\x18\x05 \x03(\t\x12\r\n\x05\x61lias\x18\x06 \x01(\t\x12\x0f\n\x07ownerID\x18\x07 \x01(\tB;\n7es.bsc.dataclay.communication.grpc.messages.logicmoduleP\x00\x62\x06proto3')



_NEWACCOUNTNOADMINREQUEST = DESCRIPTOR.message_types_by_name['NewAccountNoAdminRequest']
_NEWACCOUNTREQUEST = DESCRIPTOR.message_types_by_name['NewAccountRequest']
_NEWACCOUNTRESPONSE = DESCRIPTOR.message_types_by_name['NewAccountResponse']
_PUBLISHADDRESSREQUEST = DESCRIPTOR.message_types_by_name['PublishAddressRequest']
_GETACCOUNTIDREQUEST = DESCRIPTOR.message_types_by_name['GetAccountIDRequest']
_GETACCOUNTIDRESPONSE = DESCRIPTOR.message_types_by_name['GetAccountIDResponse']
_AUTOREGISTERSLREQUEST = DESCRIPTOR.message_types_by_name['AutoRegisterSLRequest']
_AUTOREGISTEREEREQUEST = DESCRIPTOR.message_types_by_name['AutoRegisterEERequest']
_AUTOREGISTEREERESPONSE = DESCRIPTOR.message_types_by_name['AutoRegisterEEResponse']
_UNREGISTERSTORAGELOCATIONREQUEST = DESCRIPTOR.message_types_by_name['UnregisterStorageLocationRequest']
_UNREGISTEREXECUTIONENVIRONMENTREQUEST = DESCRIPTOR.message_types_by_name['UnregisterExecutionEnvironmentRequest']
_PERFORMSETACCOUNTSREQUEST = DESCRIPTOR.message_types_by_name['PerformSetAccountsRequest']
_PERFORMSETACCOUNTSRESPONSE = DESCRIPTOR.message_types_by_name['PerformSetAccountsResponse']
_PERFORMSETOPERATIONSREQUEST = DESCRIPTOR.message_types_by_name['PerformSetOperationsRequest']
_PERFORMSETOPERATIONSRESPONSE = DESCRIPTOR.message_types_by_name['PerformSetOperationsResponse']
_GETACCOUNTLISTREQUEST = DESCRIPTOR.message_types_by_name['GetAccountListRequest']
_GETACCOUNTLISTRESPONSE = DESCRIPTOR.message_types_by_name['GetAccountListResponse']
_NEWSESSIONREQUEST = DESCRIPTOR.message_types_by_name['NewSessionRequest']
_NEWSESSIONRESPONSE = DESCRIPTOR.message_types_by_name['NewSessionResponse']
_GETINFOOFSESSIONFORDSREQUEST = DESCRIPTOR.message_types_by_name['GetInfoOfSessionForDSRequest']
_GETINFOOFSESSIONFORDSRESPONSE = DESCRIPTOR.message_types_by_name['GetInfoOfSessionForDSResponse']
_NEWNAMESPACEREQUEST = DESCRIPTOR.message_types_by_name['NewNamespaceRequest']
_NEWNAMESPACERESPONSE = DESCRIPTOR.message_types_by_name['NewNamespaceResponse']
_GETNAMESPACESREQUEST = DESCRIPTOR.message_types_by_name['GetNamespacesRequest']
_GETNAMESPACESRESPONSE = DESCRIPTOR.message_types_by_name['GetNamespacesResponse']
_REMOVENAMESPACEREQUEST = DESCRIPTOR.message_types_by_name['RemoveNamespaceRequest']
_GETNAMESPACEIDREQUEST = DESCRIPTOR.message_types_by_name['GetNamespaceIDRequest']
_GETNAMESPACEIDRESPONSE = DESCRIPTOR.message_types_by_name['GetNamespaceIDResponse']
_GETNAMESPACELANGREQUEST = DESCRIPTOR.message_types_by_name['GetNamespaceLangRequest']
_GETNAMESPACELANGRESPONSE = DESCRIPTOR.message_types_by_name['GetNamespaceLangResponse']
_GETOBJECTDATASETIDREQUEST = DESCRIPTOR.message_types_by_name['GetObjectDataSetIDRequest']
_GETOBJECTDATASETIDRESPONSE = DESCRIPTOR.message_types_by_name['GetObjectDataSetIDResponse']
_IMPORTINTERFACEREQUEST = DESCRIPTOR.message_types_by_name['ImportInterfaceRequest']
_IMPORTCONTRACTREQUEST = DESCRIPTOR.message_types_by_name['ImportContractRequest']
_NEWDATASETREQUEST = DESCRIPTOR.message_types_by_name['NewDataSetRequest']
_NEWDATASETRESPONSE = DESCRIPTOR.message_types_by_name['NewDataSetResponse']
_REMOVEDATASETREQUEST = DESCRIPTOR.message_types_by_name['RemoveDataSetRequest']
_GETDATASETIDREQUEST = DESCRIPTOR.message_types_by_name['GetDataSetIDRequest']
_GETDATASETIDRESPONSE = DESCRIPTOR.message_types_by_name['GetDataSetIDResponse']
_GETPUBLICDATASETSREQUEST = DESCRIPTOR.message_types_by_name['GetPublicDataSetsRequest']
_GETPUBLICDATASETSRESPONSE = DESCRIPTOR.message_types_by_name['GetPublicDataSetsResponse']
_GETACCOUNTDATASETSREQUEST = DESCRIPTOR.message_types_by_name['GetAccountDataSetsRequest']
_GETACCOUNTDATASETSRESPONSE = DESCRIPTOR.message_types_by_name['GetAccountDataSetsResponse']
_CHECKDATASETISPUBLICREQUEST = DESCRIPTOR.message_types_by_name['CheckDataSetIsPublicRequest']
_CHECKDATASETISPUBLICRESPONSE = DESCRIPTOR.message_types_by_name['CheckDataSetIsPublicResponse']
_NEWCLASSREQUEST = DESCRIPTOR.message_types_by_name['NewClassRequest']
_NEWCLASSREQUEST_NEWCLASSESENTRY = _NEWCLASSREQUEST.nested_types_by_name['NewClassesEntry']
_NEWCLASSRESPONSE = DESCRIPTOR.message_types_by_name['NewClassResponse']
_NEWCLASSRESPONSE_NEWCLASSESENTRY = _NEWCLASSRESPONSE.nested_types_by_name['NewClassesEntry']
_REMOVECLASSREQUEST = DESCRIPTOR.message_types_by_name['RemoveClassRequest']
_REMOVEOPERATIONREQUEST = DESCRIPTOR.message_types_by_name['RemoveOperationRequest']
_REMOVEIMPLEMENTATIONREQUEST = DESCRIPTOR.message_types_by_name['RemoveImplementationRequest']
_GETOPERATIONIDREQUEST = DESCRIPTOR.message_types_by_name['GetOperationIDRequest']
_GETOPERATIONIDRESPONSE = DESCRIPTOR.message_types_by_name['GetOperationIDResponse']
_GETPROPERTYIDREQUEST = DESCRIPTOR.message_types_by_name['GetPropertyIDRequest']
_GETPROPERTYIDRESPONSE = DESCRIPTOR.message_types_by_name['GetPropertyIDResponse']
_GETCLASSIDREQUEST = DESCRIPTOR.message_types_by_name['GetClassIDRequest']
_GETCLASSIDRESPONSE = DESCRIPTOR.message_types_by_name['GetClassIDResponse']
_GETCLASSINFOREQUEST = DESCRIPTOR.message_types_by_name['GetClassInfoRequest']
_GETCLASSINFORESPONSE = DESCRIPTOR.message_types_by_name['GetClassInfoResponse']
_GETINFOOFCLASSESINNAMESPACEREQUEST = DESCRIPTOR.message_types_by_name['GetInfoOfClassesInNamespaceRequest']
_GETINFOOFCLASSESINNAMESPACERESPONSE = DESCRIPTOR.message_types_by_name['GetInfoOfClassesInNamespaceResponse']
_GETINFOOFCLASSESINNAMESPACERESPONSE_CLASSESINFOENTRY = _GETINFOOFCLASSESINNAMESPACERESPONSE.nested_types_by_name['ClassesInfoEntry']
_GETIMPORTEDCLASSESINFOINNAMESPACEREQUEST = DESCRIPTOR.message_types_by_name['GetImportedClassesInfoInNamespaceRequest']
_GETIMPORTEDCLASSESINFOINNAMESPACERESPONSE = DESCRIPTOR.message_types_by_name['GetImportedClassesInfoInNamespaceResponse']
_GETIMPORTEDCLASSESINFOINNAMESPACERESPONSE_IMPORTEDCLASSESENTRY = _GETIMPORTEDCLASSESINFOINNAMESPACERESPONSE.nested_types_by_name['ImportedClassesEntry']
_GETCLASSIDFROMIMPORTREQUEST = DESCRIPTOR.message_types_by_name['GetClassIDFromImportRequest']
_GETCLASSIDFROMIMPORTRESPONSE = DESCRIPTOR.message_types_by_name['GetClassIDFromImportResponse']
_NEWCONTRACTREQUEST = DESCRIPTOR.message_types_by_name['NewContractRequest']
_NEWCONTRACTRESPONSE = DESCRIPTOR.message_types_by_name['NewContractResponse']
_REGISTERTOPUBLICCONTRACTREQUEST = DESCRIPTOR.message_types_by_name['RegisterToPublicContractRequest']
_REGISTERTOPUBLICCONTRACTOFNAMESPACEREQUEST = DESCRIPTOR.message_types_by_name['RegisterToPublicContractOfNamespaceRequest']
_REGISTERTOPUBLICCONTRACTOFNAMESPACERESPONSE = DESCRIPTOR.message_types_by_name['RegisterToPublicContractOfNamespaceResponse']
_GETCONTRACTIDSOFAPPLICANTREQUEST = DESCRIPTOR.message_types_by_name['GetContractIDsOfApplicantRequest']
_GETCONTRACTIDSOFAPPLICANTRESPONSE = DESCRIPTOR.message_types_by_name['GetContractIDsOfApplicantResponse']
_GETCONTRACTIDSOFAPPLICANTRESPONSE_CONTRACTSENTRY = _GETCONTRACTIDSOFAPPLICANTRESPONSE.nested_types_by_name['ContractsEntry']
_GETCONTRACTIDSOFPROVIDERREQUEST = DESCRIPTOR.message_types_by_name['GetContractIDsOfProviderRequest']
_GETCONTRACTIDSOFPROVIDERRESPONSE = DESCRIPTOR.message_types_by_name['GetContractIDsOfProviderResponse']
_GETCONTRACTIDSOFPROVIDERRESPONSE_CONTRACTSENTRY = _GETCONTRACTIDSOFPROVIDERRESPONSE.nested_types_by_name['ContractsEntry']
_GETCONTRACTSOFAPPLICANTWITHPROVREQUEST = DESCRIPTOR.message_types_by_name['GetContractsOfApplicantWithProvRequest']
_GETCONTRACTSOFAPPLICANTWITHPROVRESPONSE = DESCRIPTOR.message_types_by_name['GetContractsOfApplicantWithProvResponse']
_GETCONTRACTSOFAPPLICANTWITHPROVRESPONSE_CONTRACTSENTRY = _GETCONTRACTSOFAPPLICANTWITHPROVRESPONSE.nested_types_by_name['ContractsEntry']
_NEWDATACONTRACTREQUEST = DESCRIPTOR.message_types_by_name['NewDataContractRequest']
_NEWDATACONTRACTRESPONSE = DESCRIPTOR.message_types_by_name['NewDataContractResponse']
_REGISTERTOPUBLICDATACONTRACTREQUEST = DESCRIPTOR.message_types_by_name['RegisterToPublicDataContractRequest']
_GETDATACONTRACTIDSOFAPPLICANTREQUEST = DESCRIPTOR.message_types_by_name['GetDataContractIDsOfApplicantRequest']
_GETDATACONTRACTIDSOFAPPLICANTRESPONSE = DESCRIPTOR.message_types_by_name['GetDataContractIDsOfApplicantResponse']
_GETDATACONTRACTIDSOFAPPLICANTRESPONSE_DATACONTRACTSENTRY = _GETDATACONTRACTIDSOFAPPLICANTRESPONSE.nested_types_by_name['DatacontractsEntry']
_GETDATACONTRACTIDSOFPROVIDERREQUEST = DESCRIPTOR.message_types_by_name['GetDataContractIDsOfProviderRequest']
_GETDATACONTRACTIDSOFPROVIDERRESPONSE = DESCRIPTOR.message_types_by_name['GetDataContractIDsOfProviderResponse']
_GETDATACONTRACTIDSOFPROVIDERRESPONSE_DATACONTRACTSENTRY = _GETDATACONTRACTIDSOFPROVIDERRESPONSE.nested_types_by_name['DatacontractsEntry']
_GETDATACONTRACTINFOOFAPPLICANTWITHPROVREQUEST = DESCRIPTOR.message_types_by_name['GetDataContractInfoOfApplicantWithProvRequest']
_GETDATACONTRACTINFOOFAPPLICANTWITHPROVRESPONSE = DESCRIPTOR.message_types_by_name['GetDataContractInfoOfApplicantWithProvResponse']
_NEWINTERFACEREQUEST = DESCRIPTOR.message_types_by_name['NewInterfaceRequest']
_NEWINTERFACERESPONSE = DESCRIPTOR.message_types_by_name['NewInterfaceResponse']
_GETINTERFACEINFOREQUEST = DESCRIPTOR.message_types_by_name['GetInterfaceInfoRequest']
_GETINTERFACEINFORESPONSE = DESCRIPTOR.message_types_by_name['GetInterfaceInfoResponse']
_REMOVEINTERFACEREQUEST = DESCRIPTOR.message_types_by_name['RemoveInterfaceRequest']
_GETSTORAGELOCATIONINFOREQUEST = DESCRIPTOR.message_types_by_name['GetStorageLocationInfoRequest']
_GETSTORAGELOCATIONINFORESPONSE = DESCRIPTOR.message_types_by_name['GetStorageLocationInfoResponse']
_GETEXECUTIONENVIRONMENTINFOREQUEST = DESCRIPTOR.message_types_by_name['GetExecutionEnvironmentInfoRequest']
_GETEXECUTIONENVIRONMENTINFORESPONSE = DESCRIPTOR.message_types_by_name['GetExecutionEnvironmentInfoResponse']
_GETDATACLAYIDRESPONSE = DESCRIPTOR.message_types_by_name['GetDataClayIDResponse']
_REGISTEREXTERNALDATACLAYREQUEST = DESCRIPTOR.message_types_by_name['RegisterExternalDataClayRequest']
_REGISTEREXTERNALDATACLAYOVERRIDEAUTHORITYREQUEST = DESCRIPTOR.message_types_by_name['RegisterExternalDataClayOverrideAuthorityRequest']
_REGISTEREXTERNALDATACLAYRESPONSE = DESCRIPTOR.message_types_by_name['RegisterExternalDataClayResponse']
_NOTIFYREGISTRATIONOFEXTERNALDATACLAYREQUEST = DESCRIPTOR.message_types_by_name['NotifyRegistrationOfExternalDataClayRequest']
_NOTIFYREGISTRATIONOFEXTERNALDATACLAYRESPONSE = DESCRIPTOR.message_types_by_name['NotifyRegistrationOfExternalDataClayResponse']
_GETEXTERNALDATACLAYIDREQUEST = DESCRIPTOR.message_types_by_name['GetExternalDataclayIDRequest']
_GETEXTERNALDATACLAYIDRESPONSE = DESCRIPTOR.message_types_by_name['GetExternalDataclayIDResponse']
_GETEXTDATACLAYINFOREQUEST = DESCRIPTOR.message_types_by_name['GetExtDataClayInfoRequest']
_GETEXTDATACLAYINFORESPONSE = DESCRIPTOR.message_types_by_name['GetExtDataClayInfoResponse']
_REGISTEROBJECTFORGCREQUEST = DESCRIPTOR.message_types_by_name['RegisterObjectForGCRequest']
_REGISTEROBJECTSREQUEST = DESCRIPTOR.message_types_by_name['RegisterObjectsRequest']
_REGISTEROBJECTSRESPONSE = DESCRIPTOR.message_types_by_name['RegisterObjectsResponse']
_GETALLEXECUTIONENVIRONMENTSINFOREQUEST = DESCRIPTOR.message_types_by_name['GetAllExecutionEnvironmentsInfoRequest']
_GETALLEXECUTIONENVIRONMENTSINFORESPONSE = DESCRIPTOR.message_types_by_name['GetAllExecutionEnvironmentsInfoResponse']
_GETALLEXECUTIONENVIRONMENTSINFORESPONSE_EXECENVSENTRY = _GETALLEXECUTIONENVIRONMENTSINFORESPONSE.nested_types_by_name['ExecEnvsEntry']
_GETOBJECTINFOREQUEST = DESCRIPTOR.message_types_by_name['GetObjectInfoRequest']
_GETOBJECTINFORESPONSE = DESCRIPTOR.message_types_by_name['GetObjectInfoResponse']
_GETOBJECTFROMALIASREQUEST = DESCRIPTOR.message_types_by_name['GetObjectFromAliasRequest']
_GETOBJECTFROMALIASRESPONSE = DESCRIPTOR.message_types_by_name['GetObjectFromAliasResponse']
_ADDALIASREQUEST = DESCRIPTOR.message_types_by_name['AddAliasRequest']
_DELETEALIASREQUEST = DESCRIPTOR.message_types_by_name['DeleteAliasRequest']
_DELETEALIASRESPONSE = DESCRIPTOR.message_types_by_name['DeleteAliasResponse']
_GETOBJECTSMETADATAINFOOFCLASSFORNMREQUEST = DESCRIPTOR.message_types_by_name['GetObjectsMetaDataInfoOfClassForNMRequest']
_GETOBJECTSMETADATAINFOOFCLASSFORNMRESPONSE = DESCRIPTOR.message_types_by_name['GetObjectsMetaDataInfoOfClassForNMResponse']
_GETOBJECTSMETADATAINFOOFCLASSFORNMRESPONSE_MDATAINFOENTRY = _GETOBJECTSMETADATAINFOOFCLASSFORNMRESPONSE.nested_types_by_name['MdataInfoEntry']
_SETDATASETIDREQUEST = DESCRIPTOR.message_types_by_name['SetDataSetIDRequest']
_SETDATASETIDFROMGARBAGECOLLECTORREQUEST = DESCRIPTOR.message_types_by_name['SetDataSetIDFromGarbageCollectorRequest']
_MOVEOBJECTREQUEST = DESCRIPTOR.message_types_by_name['MoveObjectRequest']
_MOVEOBJECTRESPONSE = DESCRIPTOR.message_types_by_name['MoveObjectResponse']
_SETOBJECTREADONLYREQUEST = DESCRIPTOR.message_types_by_name['SetObjectReadOnlyRequest']
_SETOBJECTREADWRITEREQUEST = DESCRIPTOR.message_types_by_name['SetObjectReadWriteRequest']
_GETMETADATABYOIDREQUEST = DESCRIPTOR.message_types_by_name['GetMetadataByOIDRequest']
_GETMETADATABYOIDRESPONSE = DESCRIPTOR.message_types_by_name['GetMetadataByOIDResponse']
_GETMETADATABYOIDFORDSREQUEST = DESCRIPTOR.message_types_by_name['GetMetadataByOIDForDSRequest']
_GETMETADATABYOIDFORDSRESPONSE = DESCRIPTOR.message_types_by_name['GetMetadataByOIDForDSResponse']
_EXECUTEIMPLEMENTATIONREQUEST = DESCRIPTOR.message_types_by_name['ExecuteImplementationRequest']
_EXECUTEIMPLEMENTATIONRESPONSE = DESCRIPTOR.message_types_by_name['ExecuteImplementationResponse']
_EXECUTEMETHODONTARGETREQUEST = DESCRIPTOR.message_types_by_name['ExecuteMethodOnTargetRequest']
_EXECUTEMETHODONTARGETRESPONSE = DESCRIPTOR.message_types_by_name['ExecuteMethodOnTargetResponse']
_SYNCHRONIZEFEDERATEDOBJECTREQUEST = DESCRIPTOR.message_types_by_name['SynchronizeFederatedObjectRequest']
_GETSTUBSREQUEST = DESCRIPTOR.message_types_by_name['GetStubsRequest']
_GETSTUBSRESPONSE = DESCRIPTOR.message_types_by_name['GetStubsResponse']
_GETSTUBSRESPONSE_STUBSENTRY = _GETSTUBSRESPONSE.nested_types_by_name['StubsEntry']
_GETBABELSTUBSREQUEST = DESCRIPTOR.message_types_by_name['GetBabelStubsRequest']
_GETBABELSTUBSRESPONSE = DESCRIPTOR.message_types_by_name['GetBabelStubsResponse']
_GETCLASSNAMEFORDSREQUEST = DESCRIPTOR.message_types_by_name['GetClassNameForDSRequest']
_GETCLASSNAMEFORDSRESPONSE = DESCRIPTOR.message_types_by_name['GetClassNameForDSResponse']
_GETCLASSNAMEANDNAMESPACEFORDSREQUEST = DESCRIPTOR.message_types_by_name['GetClassNameAndNamespaceForDSRequest']
_GETCLASSNAMEANDNAMESPACEFORDSRESPONSE = DESCRIPTOR.message_types_by_name['GetClassNameAndNamespaceForDSResponse']
_REGISTERECAREQUEST = DESCRIPTOR.message_types_by_name['RegisterECARequest']
_ADVISEEVENTREQUEST = DESCRIPTOR.message_types_by_name['AdviseEventRequest']
_GETCONTRACTIDOFDATACLAYPROVIDERREQUEST = DESCRIPTOR.message_types_by_name['GetContractIDOfDataClayProviderRequest']
_GETCONTRACTIDOFDATACLAYPROVIDERRESPONSE = DESCRIPTOR.message_types_by_name['GetContractIDOfDataClayProviderResponse']
_ACTIVATETRACINGREQUEST = DESCRIPTOR.message_types_by_name['ActivateTracingRequest']
_CLOSESESSIONREQUEST = DESCRIPTOR.message_types_by_name['CloseSessionRequest']
_UNREGISTEROBJECTSREQUEST = DESCRIPTOR.message_types_by_name['UnregisterObjectsRequest']
_ISPREFETCHINGENABLEDRESPONSE = DESCRIPTOR.message_types_by_name['IsPrefetchingEnabledResponse']
_OBJECTEXISTSINDATACLAYREQUEST = DESCRIPTOR.message_types_by_name['ObjectExistsInDataClayRequest']
_OBJECTEXISTSINDATACLAYRESPONSE = DESCRIPTOR.message_types_by_name['ObjectExistsInDataClayResponse']
_GETCLASSESINNAMESPACEREQUEST = DESCRIPTOR.message_types_by_name['GetClassesInNamespaceRequest']
_GETCLASSESINNAMESPACERESPONSE = DESCRIPTOR.message_types_by_name['GetClassesInNamespaceResponse']
_IMPORTMODELSFROMEXTERNALDATACLAYREQUEST = DESCRIPTOR.message_types_by_name['ImportModelsFromExternalDataClayRequest']
_GETSTORAGELOCATIONIDREQUEST = DESCRIPTOR.message_types_by_name['GetStorageLocationIDRequest']
_GETSTORAGELOCATIONIDRESPONSE = DESCRIPTOR.message_types_by_name['GetStorageLocationIDResponse']
_NOTIFYEXECUTIONENVIRONMENTSHUTDOWNREQUEST = DESCRIPTOR.message_types_by_name['NotifyExecutionEnvironmentShutdownRequest']
_NOTIFYSTORAGELOCATIONSHUTDOWNREQUEST = DESCRIPTOR.message_types_by_name['NotifyStorageLocationShutdownRequest']
_EXISTSACTIVEENVIRONMENTSFORSLREQUEST = DESCRIPTOR.message_types_by_name['ExistsActiveEnvironmentsForSLRequest']
_EXISTSACTIVEENVIRONMENTSFORSLRESPONSE = DESCRIPTOR.message_types_by_name['ExistsActiveEnvironmentsForSLResponse']
_METADATAINFO = DESCRIPTOR.message_types_by_name['MetadataInfo']
NewAccountNoAdminRequest = _reflection.GeneratedProtocolMessageType('NewAccountNoAdminRequest', (_message.Message,), {
  'DESCRIPTOR' : _NEWACCOUNTNOADMINREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.NewAccountNoAdminRequest)
  })
_sym_db.RegisterMessage(NewAccountNoAdminRequest)

NewAccountRequest = _reflection.GeneratedProtocolMessageType('NewAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _NEWACCOUNTREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.NewAccountRequest)
  })
_sym_db.RegisterMessage(NewAccountRequest)

NewAccountResponse = _reflection.GeneratedProtocolMessageType('NewAccountResponse', (_message.Message,), {
  'DESCRIPTOR' : _NEWACCOUNTRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.NewAccountResponse)
  })
_sym_db.RegisterMessage(NewAccountResponse)

PublishAddressRequest = _reflection.GeneratedProtocolMessageType('PublishAddressRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHADDRESSREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.PublishAddressRequest)
  })
_sym_db.RegisterMessage(PublishAddressRequest)

GetAccountIDRequest = _reflection.GeneratedProtocolMessageType('GetAccountIDRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTIDREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetAccountIDRequest)
  })
_sym_db.RegisterMessage(GetAccountIDRequest)

GetAccountIDResponse = _reflection.GeneratedProtocolMessageType('GetAccountIDResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTIDRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetAccountIDResponse)
  })
_sym_db.RegisterMessage(GetAccountIDResponse)

AutoRegisterSLRequest = _reflection.GeneratedProtocolMessageType('AutoRegisterSLRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTOREGISTERSLREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.AutoRegisterSLRequest)
  })
_sym_db.RegisterMessage(AutoRegisterSLRequest)

AutoRegisterEERequest = _reflection.GeneratedProtocolMessageType('AutoRegisterEERequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTOREGISTEREEREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.AutoRegisterEERequest)
  })
_sym_db.RegisterMessage(AutoRegisterEERequest)

AutoRegisterEEResponse = _reflection.GeneratedProtocolMessageType('AutoRegisterEEResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTOREGISTEREERESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.AutoRegisterEEResponse)
  })
_sym_db.RegisterMessage(AutoRegisterEEResponse)

UnregisterStorageLocationRequest = _reflection.GeneratedProtocolMessageType('UnregisterStorageLocationRequest', (_message.Message,), {
  'DESCRIPTOR' : _UNREGISTERSTORAGELOCATIONREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.UnregisterStorageLocationRequest)
  })
_sym_db.RegisterMessage(UnregisterStorageLocationRequest)

UnregisterExecutionEnvironmentRequest = _reflection.GeneratedProtocolMessageType('UnregisterExecutionEnvironmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _UNREGISTEREXECUTIONENVIRONMENTREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.UnregisterExecutionEnvironmentRequest)
  })
_sym_db.RegisterMessage(UnregisterExecutionEnvironmentRequest)

PerformSetAccountsRequest = _reflection.GeneratedProtocolMessageType('PerformSetAccountsRequest', (_message.Message,), {
  'DESCRIPTOR' : _PERFORMSETACCOUNTSREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.PerformSetAccountsRequest)
  })
_sym_db.RegisterMessage(PerformSetAccountsRequest)

PerformSetAccountsResponse = _reflection.GeneratedProtocolMessageType('PerformSetAccountsResponse', (_message.Message,), {
  'DESCRIPTOR' : _PERFORMSETACCOUNTSRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.PerformSetAccountsResponse)
  })
_sym_db.RegisterMessage(PerformSetAccountsResponse)

PerformSetOperationsRequest = _reflection.GeneratedProtocolMessageType('PerformSetOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _PERFORMSETOPERATIONSREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.PerformSetOperationsRequest)
  })
_sym_db.RegisterMessage(PerformSetOperationsRequest)

PerformSetOperationsResponse = _reflection.GeneratedProtocolMessageType('PerformSetOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _PERFORMSETOPERATIONSRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.PerformSetOperationsResponse)
  })
_sym_db.RegisterMessage(PerformSetOperationsResponse)

GetAccountListRequest = _reflection.GeneratedProtocolMessageType('GetAccountListRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTLISTREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetAccountListRequest)
  })
_sym_db.RegisterMessage(GetAccountListRequest)

GetAccountListResponse = _reflection.GeneratedProtocolMessageType('GetAccountListResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTLISTRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetAccountListResponse)
  })
_sym_db.RegisterMessage(GetAccountListResponse)

NewSessionRequest = _reflection.GeneratedProtocolMessageType('NewSessionRequest', (_message.Message,), {
  'DESCRIPTOR' : _NEWSESSIONREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.NewSessionRequest)
  })
_sym_db.RegisterMessage(NewSessionRequest)

NewSessionResponse = _reflection.GeneratedProtocolMessageType('NewSessionResponse', (_message.Message,), {
  'DESCRIPTOR' : _NEWSESSIONRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.NewSessionResponse)
  })
_sym_db.RegisterMessage(NewSessionResponse)

GetInfoOfSessionForDSRequest = _reflection.GeneratedProtocolMessageType('GetInfoOfSessionForDSRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINFOOFSESSIONFORDSREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetInfoOfSessionForDSRequest)
  })
_sym_db.RegisterMessage(GetInfoOfSessionForDSRequest)

GetInfoOfSessionForDSResponse = _reflection.GeneratedProtocolMessageType('GetInfoOfSessionForDSResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETINFOOFSESSIONFORDSRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetInfoOfSessionForDSResponse)
  })
_sym_db.RegisterMessage(GetInfoOfSessionForDSResponse)

NewNamespaceRequest = _reflection.GeneratedProtocolMessageType('NewNamespaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _NEWNAMESPACEREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.NewNamespaceRequest)
  })
_sym_db.RegisterMessage(NewNamespaceRequest)

NewNamespaceResponse = _reflection.GeneratedProtocolMessageType('NewNamespaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _NEWNAMESPACERESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.NewNamespaceResponse)
  })
_sym_db.RegisterMessage(NewNamespaceResponse)

GetNamespacesRequest = _reflection.GeneratedProtocolMessageType('GetNamespacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNAMESPACESREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetNamespacesRequest)
  })
_sym_db.RegisterMessage(GetNamespacesRequest)

GetNamespacesResponse = _reflection.GeneratedProtocolMessageType('GetNamespacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNAMESPACESRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetNamespacesResponse)
  })
_sym_db.RegisterMessage(GetNamespacesResponse)

RemoveNamespaceRequest = _reflection.GeneratedProtocolMessageType('RemoveNamespaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVENAMESPACEREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.RemoveNamespaceRequest)
  })
_sym_db.RegisterMessage(RemoveNamespaceRequest)

GetNamespaceIDRequest = _reflection.GeneratedProtocolMessageType('GetNamespaceIDRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNAMESPACEIDREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetNamespaceIDRequest)
  })
_sym_db.RegisterMessage(GetNamespaceIDRequest)

GetNamespaceIDResponse = _reflection.GeneratedProtocolMessageType('GetNamespaceIDResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNAMESPACEIDRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetNamespaceIDResponse)
  })
_sym_db.RegisterMessage(GetNamespaceIDResponse)

GetNamespaceLangRequest = _reflection.GeneratedProtocolMessageType('GetNamespaceLangRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNAMESPACELANGREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetNamespaceLangRequest)
  })
_sym_db.RegisterMessage(GetNamespaceLangRequest)

GetNamespaceLangResponse = _reflection.GeneratedProtocolMessageType('GetNamespaceLangResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNAMESPACELANGRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetNamespaceLangResponse)
  })
_sym_db.RegisterMessage(GetNamespaceLangResponse)

GetObjectDataSetIDRequest = _reflection.GeneratedProtocolMessageType('GetObjectDataSetIDRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETOBJECTDATASETIDREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetObjectDataSetIDRequest)
  })
_sym_db.RegisterMessage(GetObjectDataSetIDRequest)

GetObjectDataSetIDResponse = _reflection.GeneratedProtocolMessageType('GetObjectDataSetIDResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETOBJECTDATASETIDRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetObjectDataSetIDResponse)
  })
_sym_db.RegisterMessage(GetObjectDataSetIDResponse)

ImportInterfaceRequest = _reflection.GeneratedProtocolMessageType('ImportInterfaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTINTERFACEREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.ImportInterfaceRequest)
  })
_sym_db.RegisterMessage(ImportInterfaceRequest)

ImportContractRequest = _reflection.GeneratedProtocolMessageType('ImportContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTCONTRACTREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.ImportContractRequest)
  })
_sym_db.RegisterMessage(ImportContractRequest)

NewDataSetRequest = _reflection.GeneratedProtocolMessageType('NewDataSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _NEWDATASETREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.NewDataSetRequest)
  })
_sym_db.RegisterMessage(NewDataSetRequest)

NewDataSetResponse = _reflection.GeneratedProtocolMessageType('NewDataSetResponse', (_message.Message,), {
  'DESCRIPTOR' : _NEWDATASETRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.NewDataSetResponse)
  })
_sym_db.RegisterMessage(NewDataSetResponse)

RemoveDataSetRequest = _reflection.GeneratedProtocolMessageType('RemoveDataSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEDATASETREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.RemoveDataSetRequest)
  })
_sym_db.RegisterMessage(RemoveDataSetRequest)

GetDataSetIDRequest = _reflection.GeneratedProtocolMessageType('GetDataSetIDRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASETIDREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetDataSetIDRequest)
  })
_sym_db.RegisterMessage(GetDataSetIDRequest)

GetDataSetIDResponse = _reflection.GeneratedProtocolMessageType('GetDataSetIDResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASETIDRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetDataSetIDResponse)
  })
_sym_db.RegisterMessage(GetDataSetIDResponse)

GetPublicDataSetsRequest = _reflection.GeneratedProtocolMessageType('GetPublicDataSetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPUBLICDATASETSREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetPublicDataSetsRequest)
  })
_sym_db.RegisterMessage(GetPublicDataSetsRequest)

GetPublicDataSetsResponse = _reflection.GeneratedProtocolMessageType('GetPublicDataSetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPUBLICDATASETSRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetPublicDataSetsResponse)
  })
_sym_db.RegisterMessage(GetPublicDataSetsResponse)

GetAccountDataSetsRequest = _reflection.GeneratedProtocolMessageType('GetAccountDataSetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTDATASETSREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetAccountDataSetsRequest)
  })
_sym_db.RegisterMessage(GetAccountDataSetsRequest)

GetAccountDataSetsResponse = _reflection.GeneratedProtocolMessageType('GetAccountDataSetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTDATASETSRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetAccountDataSetsResponse)
  })
_sym_db.RegisterMessage(GetAccountDataSetsResponse)

CheckDataSetIsPublicRequest = _reflection.GeneratedProtocolMessageType('CheckDataSetIsPublicRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHECKDATASETISPUBLICREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.CheckDataSetIsPublicRequest)
  })
_sym_db.RegisterMessage(CheckDataSetIsPublicRequest)

CheckDataSetIsPublicResponse = _reflection.GeneratedProtocolMessageType('CheckDataSetIsPublicResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHECKDATASETISPUBLICRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.CheckDataSetIsPublicResponse)
  })
_sym_db.RegisterMessage(CheckDataSetIsPublicResponse)

NewClassRequest = _reflection.GeneratedProtocolMessageType('NewClassRequest', (_message.Message,), {

  'NewClassesEntry' : _reflection.GeneratedProtocolMessageType('NewClassesEntry', (_message.Message,), {
    'DESCRIPTOR' : _NEWCLASSREQUEST_NEWCLASSESENTRY,
    '__module__' : 'protos.logicmodule_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.logicmodule.NewClassRequest.NewClassesEntry)
    })
  ,
  'DESCRIPTOR' : _NEWCLASSREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.NewClassRequest)
  })
_sym_db.RegisterMessage(NewClassRequest)
_sym_db.RegisterMessage(NewClassRequest.NewClassesEntry)

NewClassResponse = _reflection.GeneratedProtocolMessageType('NewClassResponse', (_message.Message,), {

  'NewClassesEntry' : _reflection.GeneratedProtocolMessageType('NewClassesEntry', (_message.Message,), {
    'DESCRIPTOR' : _NEWCLASSRESPONSE_NEWCLASSESENTRY,
    '__module__' : 'protos.logicmodule_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.logicmodule.NewClassResponse.NewClassesEntry)
    })
  ,
  'DESCRIPTOR' : _NEWCLASSRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.NewClassResponse)
  })
_sym_db.RegisterMessage(NewClassResponse)
_sym_db.RegisterMessage(NewClassResponse.NewClassesEntry)

RemoveClassRequest = _reflection.GeneratedProtocolMessageType('RemoveClassRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVECLASSREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.RemoveClassRequest)
  })
_sym_db.RegisterMessage(RemoveClassRequest)

RemoveOperationRequest = _reflection.GeneratedProtocolMessageType('RemoveOperationRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEOPERATIONREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.RemoveOperationRequest)
  })
_sym_db.RegisterMessage(RemoveOperationRequest)

RemoveImplementationRequest = _reflection.GeneratedProtocolMessageType('RemoveImplementationRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEIMPLEMENTATIONREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.RemoveImplementationRequest)
  })
_sym_db.RegisterMessage(RemoveImplementationRequest)

GetOperationIDRequest = _reflection.GeneratedProtocolMessageType('GetOperationIDRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETOPERATIONIDREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetOperationIDRequest)
  })
_sym_db.RegisterMessage(GetOperationIDRequest)

GetOperationIDResponse = _reflection.GeneratedProtocolMessageType('GetOperationIDResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETOPERATIONIDRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetOperationIDResponse)
  })
_sym_db.RegisterMessage(GetOperationIDResponse)

GetPropertyIDRequest = _reflection.GeneratedProtocolMessageType('GetPropertyIDRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROPERTYIDREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetPropertyIDRequest)
  })
_sym_db.RegisterMessage(GetPropertyIDRequest)

GetPropertyIDResponse = _reflection.GeneratedProtocolMessageType('GetPropertyIDResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPROPERTYIDRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetPropertyIDResponse)
  })
_sym_db.RegisterMessage(GetPropertyIDResponse)

GetClassIDRequest = _reflection.GeneratedProtocolMessageType('GetClassIDRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCLASSIDREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetClassIDRequest)
  })
_sym_db.RegisterMessage(GetClassIDRequest)

GetClassIDResponse = _reflection.GeneratedProtocolMessageType('GetClassIDResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCLASSIDRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetClassIDResponse)
  })
_sym_db.RegisterMessage(GetClassIDResponse)

GetClassInfoRequest = _reflection.GeneratedProtocolMessageType('GetClassInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCLASSINFOREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetClassInfoRequest)
  })
_sym_db.RegisterMessage(GetClassInfoRequest)

GetClassInfoResponse = _reflection.GeneratedProtocolMessageType('GetClassInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCLASSINFORESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetClassInfoResponse)
  })
_sym_db.RegisterMessage(GetClassInfoResponse)

GetInfoOfClassesInNamespaceRequest = _reflection.GeneratedProtocolMessageType('GetInfoOfClassesInNamespaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINFOOFCLASSESINNAMESPACEREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetInfoOfClassesInNamespaceRequest)
  })
_sym_db.RegisterMessage(GetInfoOfClassesInNamespaceRequest)

GetInfoOfClassesInNamespaceResponse = _reflection.GeneratedProtocolMessageType('GetInfoOfClassesInNamespaceResponse', (_message.Message,), {

  'ClassesInfoEntry' : _reflection.GeneratedProtocolMessageType('ClassesInfoEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETINFOOFCLASSESINNAMESPACERESPONSE_CLASSESINFOENTRY,
    '__module__' : 'protos.logicmodule_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.logicmodule.GetInfoOfClassesInNamespaceResponse.ClassesInfoEntry)
    })
  ,
  'DESCRIPTOR' : _GETINFOOFCLASSESINNAMESPACERESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetInfoOfClassesInNamespaceResponse)
  })
_sym_db.RegisterMessage(GetInfoOfClassesInNamespaceResponse)
_sym_db.RegisterMessage(GetInfoOfClassesInNamespaceResponse.ClassesInfoEntry)

GetImportedClassesInfoInNamespaceRequest = _reflection.GeneratedProtocolMessageType('GetImportedClassesInfoInNamespaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETIMPORTEDCLASSESINFOINNAMESPACEREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetImportedClassesInfoInNamespaceRequest)
  })
_sym_db.RegisterMessage(GetImportedClassesInfoInNamespaceRequest)

GetImportedClassesInfoInNamespaceResponse = _reflection.GeneratedProtocolMessageType('GetImportedClassesInfoInNamespaceResponse', (_message.Message,), {

  'ImportedClassesEntry' : _reflection.GeneratedProtocolMessageType('ImportedClassesEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETIMPORTEDCLASSESINFOINNAMESPACERESPONSE_IMPORTEDCLASSESENTRY,
    '__module__' : 'protos.logicmodule_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.logicmodule.GetImportedClassesInfoInNamespaceResponse.ImportedClassesEntry)
    })
  ,
  'DESCRIPTOR' : _GETIMPORTEDCLASSESINFOINNAMESPACERESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetImportedClassesInfoInNamespaceResponse)
  })
_sym_db.RegisterMessage(GetImportedClassesInfoInNamespaceResponse)
_sym_db.RegisterMessage(GetImportedClassesInfoInNamespaceResponse.ImportedClassesEntry)

GetClassIDFromImportRequest = _reflection.GeneratedProtocolMessageType('GetClassIDFromImportRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCLASSIDFROMIMPORTREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetClassIDFromImportRequest)
  })
_sym_db.RegisterMessage(GetClassIDFromImportRequest)

GetClassIDFromImportResponse = _reflection.GeneratedProtocolMessageType('GetClassIDFromImportResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCLASSIDFROMIMPORTRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetClassIDFromImportResponse)
  })
_sym_db.RegisterMessage(GetClassIDFromImportResponse)

NewContractRequest = _reflection.GeneratedProtocolMessageType('NewContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _NEWCONTRACTREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.NewContractRequest)
  })
_sym_db.RegisterMessage(NewContractRequest)

NewContractResponse = _reflection.GeneratedProtocolMessageType('NewContractResponse', (_message.Message,), {
  'DESCRIPTOR' : _NEWCONTRACTRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.NewContractResponse)
  })
_sym_db.RegisterMessage(NewContractResponse)

RegisterToPublicContractRequest = _reflection.GeneratedProtocolMessageType('RegisterToPublicContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERTOPUBLICCONTRACTREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.RegisterToPublicContractRequest)
  })
_sym_db.RegisterMessage(RegisterToPublicContractRequest)

RegisterToPublicContractOfNamespaceRequest = _reflection.GeneratedProtocolMessageType('RegisterToPublicContractOfNamespaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERTOPUBLICCONTRACTOFNAMESPACEREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.RegisterToPublicContractOfNamespaceRequest)
  })
_sym_db.RegisterMessage(RegisterToPublicContractOfNamespaceRequest)

RegisterToPublicContractOfNamespaceResponse = _reflection.GeneratedProtocolMessageType('RegisterToPublicContractOfNamespaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERTOPUBLICCONTRACTOFNAMESPACERESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.RegisterToPublicContractOfNamespaceResponse)
  })
_sym_db.RegisterMessage(RegisterToPublicContractOfNamespaceResponse)

GetContractIDsOfApplicantRequest = _reflection.GeneratedProtocolMessageType('GetContractIDsOfApplicantRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONTRACTIDSOFAPPLICANTREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetContractIDsOfApplicantRequest)
  })
_sym_db.RegisterMessage(GetContractIDsOfApplicantRequest)

GetContractIDsOfApplicantResponse = _reflection.GeneratedProtocolMessageType('GetContractIDsOfApplicantResponse', (_message.Message,), {

  'ContractsEntry' : _reflection.GeneratedProtocolMessageType('ContractsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETCONTRACTIDSOFAPPLICANTRESPONSE_CONTRACTSENTRY,
    '__module__' : 'protos.logicmodule_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.logicmodule.GetContractIDsOfApplicantResponse.ContractsEntry)
    })
  ,
  'DESCRIPTOR' : _GETCONTRACTIDSOFAPPLICANTRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetContractIDsOfApplicantResponse)
  })
_sym_db.RegisterMessage(GetContractIDsOfApplicantResponse)
_sym_db.RegisterMessage(GetContractIDsOfApplicantResponse.ContractsEntry)

GetContractIDsOfProviderRequest = _reflection.GeneratedProtocolMessageType('GetContractIDsOfProviderRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONTRACTIDSOFPROVIDERREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetContractIDsOfProviderRequest)
  })
_sym_db.RegisterMessage(GetContractIDsOfProviderRequest)

GetContractIDsOfProviderResponse = _reflection.GeneratedProtocolMessageType('GetContractIDsOfProviderResponse', (_message.Message,), {

  'ContractsEntry' : _reflection.GeneratedProtocolMessageType('ContractsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETCONTRACTIDSOFPROVIDERRESPONSE_CONTRACTSENTRY,
    '__module__' : 'protos.logicmodule_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.logicmodule.GetContractIDsOfProviderResponse.ContractsEntry)
    })
  ,
  'DESCRIPTOR' : _GETCONTRACTIDSOFPROVIDERRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetContractIDsOfProviderResponse)
  })
_sym_db.RegisterMessage(GetContractIDsOfProviderResponse)
_sym_db.RegisterMessage(GetContractIDsOfProviderResponse.ContractsEntry)

GetContractsOfApplicantWithProvRequest = _reflection.GeneratedProtocolMessageType('GetContractsOfApplicantWithProvRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONTRACTSOFAPPLICANTWITHPROVREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetContractsOfApplicantWithProvRequest)
  })
_sym_db.RegisterMessage(GetContractsOfApplicantWithProvRequest)

GetContractsOfApplicantWithProvResponse = _reflection.GeneratedProtocolMessageType('GetContractsOfApplicantWithProvResponse', (_message.Message,), {

  'ContractsEntry' : _reflection.GeneratedProtocolMessageType('ContractsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETCONTRACTSOFAPPLICANTWITHPROVRESPONSE_CONTRACTSENTRY,
    '__module__' : 'protos.logicmodule_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.logicmodule.GetContractsOfApplicantWithProvResponse.ContractsEntry)
    })
  ,
  'DESCRIPTOR' : _GETCONTRACTSOFAPPLICANTWITHPROVRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetContractsOfApplicantWithProvResponse)
  })
_sym_db.RegisterMessage(GetContractsOfApplicantWithProvResponse)
_sym_db.RegisterMessage(GetContractsOfApplicantWithProvResponse.ContractsEntry)

NewDataContractRequest = _reflection.GeneratedProtocolMessageType('NewDataContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _NEWDATACONTRACTREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.NewDataContractRequest)
  })
_sym_db.RegisterMessage(NewDataContractRequest)

NewDataContractResponse = _reflection.GeneratedProtocolMessageType('NewDataContractResponse', (_message.Message,), {
  'DESCRIPTOR' : _NEWDATACONTRACTRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.NewDataContractResponse)
  })
_sym_db.RegisterMessage(NewDataContractResponse)

RegisterToPublicDataContractRequest = _reflection.GeneratedProtocolMessageType('RegisterToPublicDataContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERTOPUBLICDATACONTRACTREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.RegisterToPublicDataContractRequest)
  })
_sym_db.RegisterMessage(RegisterToPublicDataContractRequest)

GetDataContractIDsOfApplicantRequest = _reflection.GeneratedProtocolMessageType('GetDataContractIDsOfApplicantRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATACONTRACTIDSOFAPPLICANTREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetDataContractIDsOfApplicantRequest)
  })
_sym_db.RegisterMessage(GetDataContractIDsOfApplicantRequest)

GetDataContractIDsOfApplicantResponse = _reflection.GeneratedProtocolMessageType('GetDataContractIDsOfApplicantResponse', (_message.Message,), {

  'DatacontractsEntry' : _reflection.GeneratedProtocolMessageType('DatacontractsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETDATACONTRACTIDSOFAPPLICANTRESPONSE_DATACONTRACTSENTRY,
    '__module__' : 'protos.logicmodule_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.logicmodule.GetDataContractIDsOfApplicantResponse.DatacontractsEntry)
    })
  ,
  'DESCRIPTOR' : _GETDATACONTRACTIDSOFAPPLICANTRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetDataContractIDsOfApplicantResponse)
  })
_sym_db.RegisterMessage(GetDataContractIDsOfApplicantResponse)
_sym_db.RegisterMessage(GetDataContractIDsOfApplicantResponse.DatacontractsEntry)

GetDataContractIDsOfProviderRequest = _reflection.GeneratedProtocolMessageType('GetDataContractIDsOfProviderRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATACONTRACTIDSOFPROVIDERREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetDataContractIDsOfProviderRequest)
  })
_sym_db.RegisterMessage(GetDataContractIDsOfProviderRequest)

GetDataContractIDsOfProviderResponse = _reflection.GeneratedProtocolMessageType('GetDataContractIDsOfProviderResponse', (_message.Message,), {

  'DatacontractsEntry' : _reflection.GeneratedProtocolMessageType('DatacontractsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETDATACONTRACTIDSOFPROVIDERRESPONSE_DATACONTRACTSENTRY,
    '__module__' : 'protos.logicmodule_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.logicmodule.GetDataContractIDsOfProviderResponse.DatacontractsEntry)
    })
  ,
  'DESCRIPTOR' : _GETDATACONTRACTIDSOFPROVIDERRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetDataContractIDsOfProviderResponse)
  })
_sym_db.RegisterMessage(GetDataContractIDsOfProviderResponse)
_sym_db.RegisterMessage(GetDataContractIDsOfProviderResponse.DatacontractsEntry)

GetDataContractInfoOfApplicantWithProvRequest = _reflection.GeneratedProtocolMessageType('GetDataContractInfoOfApplicantWithProvRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATACONTRACTINFOOFAPPLICANTWITHPROVREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetDataContractInfoOfApplicantWithProvRequest)
  })
_sym_db.RegisterMessage(GetDataContractInfoOfApplicantWithProvRequest)

GetDataContractInfoOfApplicantWithProvResponse = _reflection.GeneratedProtocolMessageType('GetDataContractInfoOfApplicantWithProvResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATACONTRACTINFOOFAPPLICANTWITHPROVRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetDataContractInfoOfApplicantWithProvResponse)
  })
_sym_db.RegisterMessage(GetDataContractInfoOfApplicantWithProvResponse)

NewInterfaceRequest = _reflection.GeneratedProtocolMessageType('NewInterfaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _NEWINTERFACEREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.NewInterfaceRequest)
  })
_sym_db.RegisterMessage(NewInterfaceRequest)

NewInterfaceResponse = _reflection.GeneratedProtocolMessageType('NewInterfaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _NEWINTERFACERESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.NewInterfaceResponse)
  })
_sym_db.RegisterMessage(NewInterfaceResponse)

GetInterfaceInfoRequest = _reflection.GeneratedProtocolMessageType('GetInterfaceInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINTERFACEINFOREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetInterfaceInfoRequest)
  })
_sym_db.RegisterMessage(GetInterfaceInfoRequest)

GetInterfaceInfoResponse = _reflection.GeneratedProtocolMessageType('GetInterfaceInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETINTERFACEINFORESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetInterfaceInfoResponse)
  })
_sym_db.RegisterMessage(GetInterfaceInfoResponse)

RemoveInterfaceRequest = _reflection.GeneratedProtocolMessageType('RemoveInterfaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEINTERFACEREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.RemoveInterfaceRequest)
  })
_sym_db.RegisterMessage(RemoveInterfaceRequest)

GetStorageLocationInfoRequest = _reflection.GeneratedProtocolMessageType('GetStorageLocationInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTORAGELOCATIONINFOREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetStorageLocationInfoRequest)
  })
_sym_db.RegisterMessage(GetStorageLocationInfoRequest)

GetStorageLocationInfoResponse = _reflection.GeneratedProtocolMessageType('GetStorageLocationInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSTORAGELOCATIONINFORESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetStorageLocationInfoResponse)
  })
_sym_db.RegisterMessage(GetStorageLocationInfoResponse)

GetExecutionEnvironmentInfoRequest = _reflection.GeneratedProtocolMessageType('GetExecutionEnvironmentInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETEXECUTIONENVIRONMENTINFOREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetExecutionEnvironmentInfoRequest)
  })
_sym_db.RegisterMessage(GetExecutionEnvironmentInfoRequest)

GetExecutionEnvironmentInfoResponse = _reflection.GeneratedProtocolMessageType('GetExecutionEnvironmentInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETEXECUTIONENVIRONMENTINFORESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetExecutionEnvironmentInfoResponse)
  })
_sym_db.RegisterMessage(GetExecutionEnvironmentInfoResponse)

GetDataClayIDResponse = _reflection.GeneratedProtocolMessageType('GetDataClayIDResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATACLAYIDRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetDataClayIDResponse)
  })
_sym_db.RegisterMessage(GetDataClayIDResponse)

RegisterExternalDataClayRequest = _reflection.GeneratedProtocolMessageType('RegisterExternalDataClayRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTEREXTERNALDATACLAYREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.RegisterExternalDataClayRequest)
  })
_sym_db.RegisterMessage(RegisterExternalDataClayRequest)

RegisterExternalDataClayOverrideAuthorityRequest = _reflection.GeneratedProtocolMessageType('RegisterExternalDataClayOverrideAuthorityRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTEREXTERNALDATACLAYOVERRIDEAUTHORITYREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.RegisterExternalDataClayOverrideAuthorityRequest)
  })
_sym_db.RegisterMessage(RegisterExternalDataClayOverrideAuthorityRequest)

RegisterExternalDataClayResponse = _reflection.GeneratedProtocolMessageType('RegisterExternalDataClayResponse', (_message.Message,), {
  'DESCRIPTOR' : _REGISTEREXTERNALDATACLAYRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.RegisterExternalDataClayResponse)
  })
_sym_db.RegisterMessage(RegisterExternalDataClayResponse)

NotifyRegistrationOfExternalDataClayRequest = _reflection.GeneratedProtocolMessageType('NotifyRegistrationOfExternalDataClayRequest', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYREGISTRATIONOFEXTERNALDATACLAYREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.NotifyRegistrationOfExternalDataClayRequest)
  })
_sym_db.RegisterMessage(NotifyRegistrationOfExternalDataClayRequest)

NotifyRegistrationOfExternalDataClayResponse = _reflection.GeneratedProtocolMessageType('NotifyRegistrationOfExternalDataClayResponse', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYREGISTRATIONOFEXTERNALDATACLAYRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.NotifyRegistrationOfExternalDataClayResponse)
  })
_sym_db.RegisterMessage(NotifyRegistrationOfExternalDataClayResponse)

GetExternalDataclayIDRequest = _reflection.GeneratedProtocolMessageType('GetExternalDataclayIDRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETEXTERNALDATACLAYIDREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetExternalDataclayIDRequest)
  })
_sym_db.RegisterMessage(GetExternalDataclayIDRequest)

GetExternalDataclayIDResponse = _reflection.GeneratedProtocolMessageType('GetExternalDataclayIDResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETEXTERNALDATACLAYIDRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetExternalDataclayIDResponse)
  })
_sym_db.RegisterMessage(GetExternalDataclayIDResponse)

GetExtDataClayInfoRequest = _reflection.GeneratedProtocolMessageType('GetExtDataClayInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETEXTDATACLAYINFOREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetExtDataClayInfoRequest)
  })
_sym_db.RegisterMessage(GetExtDataClayInfoRequest)

GetExtDataClayInfoResponse = _reflection.GeneratedProtocolMessageType('GetExtDataClayInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETEXTDATACLAYINFORESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetExtDataClayInfoResponse)
  })
_sym_db.RegisterMessage(GetExtDataClayInfoResponse)

RegisterObjectForGCRequest = _reflection.GeneratedProtocolMessageType('RegisterObjectForGCRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTEROBJECTFORGCREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.RegisterObjectForGCRequest)
  })
_sym_db.RegisterMessage(RegisterObjectForGCRequest)

RegisterObjectsRequest = _reflection.GeneratedProtocolMessageType('RegisterObjectsRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTEROBJECTSREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.RegisterObjectsRequest)
  })
_sym_db.RegisterMessage(RegisterObjectsRequest)

RegisterObjectsResponse = _reflection.GeneratedProtocolMessageType('RegisterObjectsResponse', (_message.Message,), {
  'DESCRIPTOR' : _REGISTEROBJECTSRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.RegisterObjectsResponse)
  })
_sym_db.RegisterMessage(RegisterObjectsResponse)

GetAllExecutionEnvironmentsInfoRequest = _reflection.GeneratedProtocolMessageType('GetAllExecutionEnvironmentsInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLEXECUTIONENVIRONMENTSINFOREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetAllExecutionEnvironmentsInfoRequest)
  })
_sym_db.RegisterMessage(GetAllExecutionEnvironmentsInfoRequest)

GetAllExecutionEnvironmentsInfoResponse = _reflection.GeneratedProtocolMessageType('GetAllExecutionEnvironmentsInfoResponse', (_message.Message,), {

  'ExecEnvsEntry' : _reflection.GeneratedProtocolMessageType('ExecEnvsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETALLEXECUTIONENVIRONMENTSINFORESPONSE_EXECENVSENTRY,
    '__module__' : 'protos.logicmodule_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.logicmodule.GetAllExecutionEnvironmentsInfoResponse.ExecEnvsEntry)
    })
  ,
  'DESCRIPTOR' : _GETALLEXECUTIONENVIRONMENTSINFORESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetAllExecutionEnvironmentsInfoResponse)
  })
_sym_db.RegisterMessage(GetAllExecutionEnvironmentsInfoResponse)
_sym_db.RegisterMessage(GetAllExecutionEnvironmentsInfoResponse.ExecEnvsEntry)

GetObjectInfoRequest = _reflection.GeneratedProtocolMessageType('GetObjectInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETOBJECTINFOREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetObjectInfoRequest)
  })
_sym_db.RegisterMessage(GetObjectInfoRequest)

GetObjectInfoResponse = _reflection.GeneratedProtocolMessageType('GetObjectInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETOBJECTINFORESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetObjectInfoResponse)
  })
_sym_db.RegisterMessage(GetObjectInfoResponse)

GetObjectFromAliasRequest = _reflection.GeneratedProtocolMessageType('GetObjectFromAliasRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETOBJECTFROMALIASREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetObjectFromAliasRequest)
  })
_sym_db.RegisterMessage(GetObjectFromAliasRequest)

GetObjectFromAliasResponse = _reflection.GeneratedProtocolMessageType('GetObjectFromAliasResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETOBJECTFROMALIASRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetObjectFromAliasResponse)
  })
_sym_db.RegisterMessage(GetObjectFromAliasResponse)

AddAliasRequest = _reflection.GeneratedProtocolMessageType('AddAliasRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDALIASREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.AddAliasRequest)
  })
_sym_db.RegisterMessage(AddAliasRequest)

DeleteAliasRequest = _reflection.GeneratedProtocolMessageType('DeleteAliasRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEALIASREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.DeleteAliasRequest)
  })
_sym_db.RegisterMessage(DeleteAliasRequest)

DeleteAliasResponse = _reflection.GeneratedProtocolMessageType('DeleteAliasResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEALIASRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.DeleteAliasResponse)
  })
_sym_db.RegisterMessage(DeleteAliasResponse)

GetObjectsMetaDataInfoOfClassForNMRequest = _reflection.GeneratedProtocolMessageType('GetObjectsMetaDataInfoOfClassForNMRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETOBJECTSMETADATAINFOOFCLASSFORNMREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetObjectsMetaDataInfoOfClassForNMRequest)
  })
_sym_db.RegisterMessage(GetObjectsMetaDataInfoOfClassForNMRequest)

GetObjectsMetaDataInfoOfClassForNMResponse = _reflection.GeneratedProtocolMessageType('GetObjectsMetaDataInfoOfClassForNMResponse', (_message.Message,), {

  'MdataInfoEntry' : _reflection.GeneratedProtocolMessageType('MdataInfoEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETOBJECTSMETADATAINFOOFCLASSFORNMRESPONSE_MDATAINFOENTRY,
    '__module__' : 'protos.logicmodule_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.logicmodule.GetObjectsMetaDataInfoOfClassForNMResponse.MdataInfoEntry)
    })
  ,
  'DESCRIPTOR' : _GETOBJECTSMETADATAINFOOFCLASSFORNMRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetObjectsMetaDataInfoOfClassForNMResponse)
  })
_sym_db.RegisterMessage(GetObjectsMetaDataInfoOfClassForNMResponse)
_sym_db.RegisterMessage(GetObjectsMetaDataInfoOfClassForNMResponse.MdataInfoEntry)

SetDataSetIDRequest = _reflection.GeneratedProtocolMessageType('SetDataSetIDRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETDATASETIDREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.SetDataSetIDRequest)
  })
_sym_db.RegisterMessage(SetDataSetIDRequest)

SetDataSetIDFromGarbageCollectorRequest = _reflection.GeneratedProtocolMessageType('SetDataSetIDFromGarbageCollectorRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETDATASETIDFROMGARBAGECOLLECTORREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.SetDataSetIDFromGarbageCollectorRequest)
  })
_sym_db.RegisterMessage(SetDataSetIDFromGarbageCollectorRequest)

MoveObjectRequest = _reflection.GeneratedProtocolMessageType('MoveObjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _MOVEOBJECTREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.MoveObjectRequest)
  })
_sym_db.RegisterMessage(MoveObjectRequest)

MoveObjectResponse = _reflection.GeneratedProtocolMessageType('MoveObjectResponse', (_message.Message,), {
  'DESCRIPTOR' : _MOVEOBJECTRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.MoveObjectResponse)
  })
_sym_db.RegisterMessage(MoveObjectResponse)

SetObjectReadOnlyRequest = _reflection.GeneratedProtocolMessageType('SetObjectReadOnlyRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETOBJECTREADONLYREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.SetObjectReadOnlyRequest)
  })
_sym_db.RegisterMessage(SetObjectReadOnlyRequest)

SetObjectReadWriteRequest = _reflection.GeneratedProtocolMessageType('SetObjectReadWriteRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETOBJECTREADWRITEREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.SetObjectReadWriteRequest)
  })
_sym_db.RegisterMessage(SetObjectReadWriteRequest)

GetMetadataByOIDRequest = _reflection.GeneratedProtocolMessageType('GetMetadataByOIDRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMETADATABYOIDREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetMetadataByOIDRequest)
  })
_sym_db.RegisterMessage(GetMetadataByOIDRequest)

GetMetadataByOIDResponse = _reflection.GeneratedProtocolMessageType('GetMetadataByOIDResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMETADATABYOIDRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetMetadataByOIDResponse)
  })
_sym_db.RegisterMessage(GetMetadataByOIDResponse)

GetMetadataByOIDForDSRequest = _reflection.GeneratedProtocolMessageType('GetMetadataByOIDForDSRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMETADATABYOIDFORDSREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetMetadataByOIDForDSRequest)
  })
_sym_db.RegisterMessage(GetMetadataByOIDForDSRequest)

GetMetadataByOIDForDSResponse = _reflection.GeneratedProtocolMessageType('GetMetadataByOIDForDSResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMETADATABYOIDFORDSRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetMetadataByOIDForDSResponse)
  })
_sym_db.RegisterMessage(GetMetadataByOIDForDSResponse)

ExecuteImplementationRequest = _reflection.GeneratedProtocolMessageType('ExecuteImplementationRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTEIMPLEMENTATIONREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.ExecuteImplementationRequest)
  })
_sym_db.RegisterMessage(ExecuteImplementationRequest)

ExecuteImplementationResponse = _reflection.GeneratedProtocolMessageType('ExecuteImplementationResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTEIMPLEMENTATIONRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.ExecuteImplementationResponse)
  })
_sym_db.RegisterMessage(ExecuteImplementationResponse)

ExecuteMethodOnTargetRequest = _reflection.GeneratedProtocolMessageType('ExecuteMethodOnTargetRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTEMETHODONTARGETREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.ExecuteMethodOnTargetRequest)
  })
_sym_db.RegisterMessage(ExecuteMethodOnTargetRequest)

ExecuteMethodOnTargetResponse = _reflection.GeneratedProtocolMessageType('ExecuteMethodOnTargetResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTEMETHODONTARGETRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.ExecuteMethodOnTargetResponse)
  })
_sym_db.RegisterMessage(ExecuteMethodOnTargetResponse)

SynchronizeFederatedObjectRequest = _reflection.GeneratedProtocolMessageType('SynchronizeFederatedObjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _SYNCHRONIZEFEDERATEDOBJECTREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.SynchronizeFederatedObjectRequest)
  })
_sym_db.RegisterMessage(SynchronizeFederatedObjectRequest)

GetStubsRequest = _reflection.GeneratedProtocolMessageType('GetStubsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTUBSREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetStubsRequest)
  })
_sym_db.RegisterMessage(GetStubsRequest)

GetStubsResponse = _reflection.GeneratedProtocolMessageType('GetStubsResponse', (_message.Message,), {

  'StubsEntry' : _reflection.GeneratedProtocolMessageType('StubsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETSTUBSRESPONSE_STUBSENTRY,
    '__module__' : 'protos.logicmodule_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.logicmodule.GetStubsResponse.StubsEntry)
    })
  ,
  'DESCRIPTOR' : _GETSTUBSRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetStubsResponse)
  })
_sym_db.RegisterMessage(GetStubsResponse)
_sym_db.RegisterMessage(GetStubsResponse.StubsEntry)

GetBabelStubsRequest = _reflection.GeneratedProtocolMessageType('GetBabelStubsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBABELSTUBSREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetBabelStubsRequest)
  })
_sym_db.RegisterMessage(GetBabelStubsRequest)

GetBabelStubsResponse = _reflection.GeneratedProtocolMessageType('GetBabelStubsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBABELSTUBSRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetBabelStubsResponse)
  })
_sym_db.RegisterMessage(GetBabelStubsResponse)

GetClassNameForDSRequest = _reflection.GeneratedProtocolMessageType('GetClassNameForDSRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCLASSNAMEFORDSREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetClassNameForDSRequest)
  })
_sym_db.RegisterMessage(GetClassNameForDSRequest)

GetClassNameForDSResponse = _reflection.GeneratedProtocolMessageType('GetClassNameForDSResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCLASSNAMEFORDSRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetClassNameForDSResponse)
  })
_sym_db.RegisterMessage(GetClassNameForDSResponse)

GetClassNameAndNamespaceForDSRequest = _reflection.GeneratedProtocolMessageType('GetClassNameAndNamespaceForDSRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCLASSNAMEANDNAMESPACEFORDSREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetClassNameAndNamespaceForDSRequest)
  })
_sym_db.RegisterMessage(GetClassNameAndNamespaceForDSRequest)

GetClassNameAndNamespaceForDSResponse = _reflection.GeneratedProtocolMessageType('GetClassNameAndNamespaceForDSResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCLASSNAMEANDNAMESPACEFORDSRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetClassNameAndNamespaceForDSResponse)
  })
_sym_db.RegisterMessage(GetClassNameAndNamespaceForDSResponse)

RegisterECARequest = _reflection.GeneratedProtocolMessageType('RegisterECARequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERECAREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.RegisterECARequest)
  })
_sym_db.RegisterMessage(RegisterECARequest)

AdviseEventRequest = _reflection.GeneratedProtocolMessageType('AdviseEventRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADVISEEVENTREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.AdviseEventRequest)
  })
_sym_db.RegisterMessage(AdviseEventRequest)

GetContractIDOfDataClayProviderRequest = _reflection.GeneratedProtocolMessageType('GetContractIDOfDataClayProviderRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONTRACTIDOFDATACLAYPROVIDERREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetContractIDOfDataClayProviderRequest)
  })
_sym_db.RegisterMessage(GetContractIDOfDataClayProviderRequest)

GetContractIDOfDataClayProviderResponse = _reflection.GeneratedProtocolMessageType('GetContractIDOfDataClayProviderResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCONTRACTIDOFDATACLAYPROVIDERRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetContractIDOfDataClayProviderResponse)
  })
_sym_db.RegisterMessage(GetContractIDOfDataClayProviderResponse)

ActivateTracingRequest = _reflection.GeneratedProtocolMessageType('ActivateTracingRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATETRACINGREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.ActivateTracingRequest)
  })
_sym_db.RegisterMessage(ActivateTracingRequest)

CloseSessionRequest = _reflection.GeneratedProtocolMessageType('CloseSessionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLOSESESSIONREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.CloseSessionRequest)
  })
_sym_db.RegisterMessage(CloseSessionRequest)

UnregisterObjectsRequest = _reflection.GeneratedProtocolMessageType('UnregisterObjectsRequest', (_message.Message,), {
  'DESCRIPTOR' : _UNREGISTEROBJECTSREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.UnregisterObjectsRequest)
  })
_sym_db.RegisterMessage(UnregisterObjectsRequest)

IsPrefetchingEnabledResponse = _reflection.GeneratedProtocolMessageType('IsPrefetchingEnabledResponse', (_message.Message,), {
  'DESCRIPTOR' : _ISPREFETCHINGENABLEDRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.IsPrefetchingEnabledResponse)
  })
_sym_db.RegisterMessage(IsPrefetchingEnabledResponse)

ObjectExistsInDataClayRequest = _reflection.GeneratedProtocolMessageType('ObjectExistsInDataClayRequest', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTEXISTSINDATACLAYREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.ObjectExistsInDataClayRequest)
  })
_sym_db.RegisterMessage(ObjectExistsInDataClayRequest)

ObjectExistsInDataClayResponse = _reflection.GeneratedProtocolMessageType('ObjectExistsInDataClayResponse', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTEXISTSINDATACLAYRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.ObjectExistsInDataClayResponse)
  })
_sym_db.RegisterMessage(ObjectExistsInDataClayResponse)

GetClassesInNamespaceRequest = _reflection.GeneratedProtocolMessageType('GetClassesInNamespaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCLASSESINNAMESPACEREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetClassesInNamespaceRequest)
  })
_sym_db.RegisterMessage(GetClassesInNamespaceRequest)

GetClassesInNamespaceResponse = _reflection.GeneratedProtocolMessageType('GetClassesInNamespaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCLASSESINNAMESPACERESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetClassesInNamespaceResponse)
  })
_sym_db.RegisterMessage(GetClassesInNamespaceResponse)

ImportModelsFromExternalDataClayRequest = _reflection.GeneratedProtocolMessageType('ImportModelsFromExternalDataClayRequest', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTMODELSFROMEXTERNALDATACLAYREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.ImportModelsFromExternalDataClayRequest)
  })
_sym_db.RegisterMessage(ImportModelsFromExternalDataClayRequest)

GetStorageLocationIDRequest = _reflection.GeneratedProtocolMessageType('GetStorageLocationIDRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTORAGELOCATIONIDREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetStorageLocationIDRequest)
  })
_sym_db.RegisterMessage(GetStorageLocationIDRequest)

GetStorageLocationIDResponse = _reflection.GeneratedProtocolMessageType('GetStorageLocationIDResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSTORAGELOCATIONIDRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.GetStorageLocationIDResponse)
  })
_sym_db.RegisterMessage(GetStorageLocationIDResponse)

NotifyExecutionEnvironmentShutdownRequest = _reflection.GeneratedProtocolMessageType('NotifyExecutionEnvironmentShutdownRequest', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYEXECUTIONENVIRONMENTSHUTDOWNREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.NotifyExecutionEnvironmentShutdownRequest)
  })
_sym_db.RegisterMessage(NotifyExecutionEnvironmentShutdownRequest)

NotifyStorageLocationShutdownRequest = _reflection.GeneratedProtocolMessageType('NotifyStorageLocationShutdownRequest', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYSTORAGELOCATIONSHUTDOWNREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.NotifyStorageLocationShutdownRequest)
  })
_sym_db.RegisterMessage(NotifyStorageLocationShutdownRequest)

ExistsActiveEnvironmentsForSLRequest = _reflection.GeneratedProtocolMessageType('ExistsActiveEnvironmentsForSLRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXISTSACTIVEENVIRONMENTSFORSLREQUEST,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.ExistsActiveEnvironmentsForSLRequest)
  })
_sym_db.RegisterMessage(ExistsActiveEnvironmentsForSLRequest)

ExistsActiveEnvironmentsForSLResponse = _reflection.GeneratedProtocolMessageType('ExistsActiveEnvironmentsForSLResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXISTSACTIVEENVIRONMENTSFORSLRESPONSE,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.ExistsActiveEnvironmentsForSLResponse)
  })
_sym_db.RegisterMessage(ExistsActiveEnvironmentsForSLResponse)

MetadataInfo = _reflection.GeneratedProtocolMessageType('MetadataInfo', (_message.Message,), {
  'DESCRIPTOR' : _METADATAINFO,
  '__module__' : 'protos.logicmodule_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.logicmodule.MetadataInfo)
  })
_sym_db.RegisterMessage(MetadataInfo)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7es.bsc.dataclay.communication.grpc.messages.logicmoduleP\000'
  _NEWCLASSREQUEST_NEWCLASSESENTRY._options = None
  _NEWCLASSREQUEST_NEWCLASSESENTRY._serialized_options = b'8\001'
  _NEWCLASSRESPONSE_NEWCLASSESENTRY._options = None
  _NEWCLASSRESPONSE_NEWCLASSESENTRY._serialized_options = b'8\001'
  _GETINFOOFCLASSESINNAMESPACERESPONSE_CLASSESINFOENTRY._options = None
  _GETINFOOFCLASSESINNAMESPACERESPONSE_CLASSESINFOENTRY._serialized_options = b'8\001'
  _GETIMPORTEDCLASSESINFOINNAMESPACERESPONSE_IMPORTEDCLASSESENTRY._options = None
  _GETIMPORTEDCLASSESINFOINNAMESPACERESPONSE_IMPORTEDCLASSESENTRY._serialized_options = b'8\001'
  _GETCONTRACTIDSOFAPPLICANTRESPONSE_CONTRACTSENTRY._options = None
  _GETCONTRACTIDSOFAPPLICANTRESPONSE_CONTRACTSENTRY._serialized_options = b'8\001'
  _GETCONTRACTIDSOFPROVIDERRESPONSE_CONTRACTSENTRY._options = None
  _GETCONTRACTIDSOFPROVIDERRESPONSE_CONTRACTSENTRY._serialized_options = b'8\001'
  _GETCONTRACTSOFAPPLICANTWITHPROVRESPONSE_CONTRACTSENTRY._options = None
  _GETCONTRACTSOFAPPLICANTWITHPROVRESPONSE_CONTRACTSENTRY._serialized_options = b'8\001'
  _GETDATACONTRACTIDSOFAPPLICANTRESPONSE_DATACONTRACTSENTRY._options = None
  _GETDATACONTRACTIDSOFAPPLICANTRESPONSE_DATACONTRACTSENTRY._serialized_options = b'8\001'
  _GETDATACONTRACTIDSOFPROVIDERRESPONSE_DATACONTRACTSENTRY._options = None
  _GETDATACONTRACTIDSOFPROVIDERRESPONSE_DATACONTRACTSENTRY._serialized_options = b'8\001'
  _GETALLEXECUTIONENVIRONMENTSINFORESPONSE_EXECENVSENTRY._options = None
  _GETALLEXECUTIONENVIRONMENTSINFORESPONSE_EXECENVSENTRY._serialized_options = b'8\001'
  _GETOBJECTSMETADATAINFOOFCLASSFORNMRESPONSE_MDATAINFOENTRY._options = None
  _GETOBJECTSMETADATAINFOOFCLASSFORNMRESPONSE_MDATAINFOENTRY._serialized_options = b'8\001'
  _GETSTUBSRESPONSE_STUBSENTRY._options = None
  _GETSTUBSRESPONSE_STUBSENTRY._serialized_options = b'8\001'
  _NEWACCOUNTNOADMINREQUEST._serialized_start=87
  _NEWACCOUNTNOADMINREQUEST._serialized_end=137
  _NEWACCOUNTREQUEST._serialized_start=139
  _NEWACCOUNTREQUEST._serialized_end=251
  _NEWACCOUNTRESPONSE._serialized_start=253
  _NEWACCOUNTRESPONSE._serialized_end=342
  _PUBLISHADDRESSREQUEST._serialized_start=344
  _PUBLISHADDRESSREQUEST._serialized_end=399
  _GETACCOUNTIDREQUEST._serialized_start=401
  _GETACCOUNTIDREQUEST._serialized_end=443
  _GETACCOUNTIDRESPONSE._serialized_start=445
  _GETACCOUNTIDRESPONSE._serialized_end=536
  _AUTOREGISTERSLREQUEST._serialized_start=538
  _AUTOREGISTERSLREQUEST._serialized_end=640
  _AUTOREGISTEREEREQUEST._serialized_start=643
  _AUTOREGISTEREEREQUEST._serialized_end=786
  _AUTOREGISTEREERESPONSE._serialized_start=788
  _AUTOREGISTEREERESPONSE._serialized_end=886
  _UNREGISTERSTORAGELOCATIONREQUEST._serialized_start=888
  _UNREGISTERSTORAGELOCATIONREQUEST._serialized_end=949
  _UNREGISTEREXECUTIONENVIRONMENTREQUEST._serialized_start=951
  _UNREGISTEREXECUTIONENVIRONMENTREQUEST._serialized_end=1022
  _PERFORMSETACCOUNTSREQUEST._serialized_start=1024
  _PERFORMSETACCOUNTSREQUEST._serialized_end=1131
  _PERFORMSETACCOUNTSRESPONSE._serialized_start=1133
  _PERFORMSETACCOUNTSRESPONSE._serialized_end=1228
  _PERFORMSETOPERATIONSREQUEST._serialized_start=1230
  _PERFORMSETOPERATIONSREQUEST._serialized_end=1339
  _PERFORMSETOPERATIONSRESPONSE._serialized_start=1341
  _PERFORMSETOPERATIONSRESPONSE._serialized_end=1438
  _GETACCOUNTLISTREQUEST._serialized_start=1440
  _GETACCOUNTLISTREQUEST._serialized_end=1532
  _GETACCOUNTLISTRESPONSE._serialized_start=1534
  _GETACCOUNTLISTRESPONSE._serialized_end=1625
  _NEWSESSIONREQUEST._serialized_start=1628
  _NEWSESSIONREQUEST._serialized_end=1819
  _NEWSESSIONRESPONSE._serialized_start=1821
  _NEWSESSIONRESPONSE._serialized_end=1909
  _GETINFOOFSESSIONFORDSREQUEST._serialized_start=1911
  _GETINFOOFSESSIONFORDSREQUEST._serialized_end=1960
  _GETINFOOFSESSIONFORDSRESPONSE._serialized_start=1963
  _GETINFOOFSESSIONFORDSRESPONSE._serialized_end=2094
  _NEWNAMESPACEREQUEST._serialized_start=2096
  _NEWNAMESPACEREQUEST._serialized_end=2209
  _NEWNAMESPACERESPONSE._serialized_start=2211
  _NEWNAMESPACERESPONSE._serialized_end=2301
  _GETNAMESPACESREQUEST._serialized_start=2303
  _GETNAMESPACESREQUEST._serialized_end=2391
  _GETNAMESPACESRESPONSE._serialized_start=2393
  _GETNAMESPACESRESPONSE._serialized_end=2483
  _REMOVENAMESPACEREQUEST._serialized_start=2485
  _REMOVENAMESPACEREQUEST._serialized_end=2598
  _GETNAMESPACEIDREQUEST._serialized_start=2600
  _GETNAMESPACEIDREQUEST._serialized_end=2712
  _GETNAMESPACEIDRESPONSE._serialized_start=2714
  _GETNAMESPACEIDRESPONSE._serialized_end=2806
  _GETNAMESPACELANGREQUEST._serialized_start=2808
  _GETNAMESPACELANGREQUEST._serialized_end=2922
  _GETNAMESPACELANGRESPONSE._serialized_start=2924
  _GETNAMESPACELANGRESPONSE._serialized_end=3037
  _GETOBJECTDATASETIDREQUEST._serialized_start=3039
  _GETOBJECTDATASETIDREQUEST._serialized_end=3103
  _GETOBJECTDATASETIDRESPONSE._serialized_start=3105
  _GETOBJECTDATASETIDRESPONSE._serialized_end=3199
  _IMPORTINTERFACEREQUEST._serialized_start=3202
  _IMPORTINTERFACEREQUEST._serialized_end=3354
  _IMPORTCONTRACTREQUEST._serialized_start=3357
  _IMPORTCONTRACTREQUEST._serialized_end=3487
  _NEWDATASETREQUEST._serialized_start=3489
  _NEWDATASETREQUEST._serialized_end=3595
  _NEWDATASETRESPONSE._serialized_start=3597
  _NEWDATASETRESPONSE._serialized_end=3683
  _REMOVEDATASETREQUEST._serialized_start=3685
  _REMOVEDATASETREQUEST._serialized_end=3794
  _GETDATASETIDREQUEST._serialized_start=3796
  _GETDATASETIDREQUEST._serialized_end=3904
  _GETDATASETIDRESPONSE._serialized_start=3906
  _GETDATASETIDRESPONSE._serialized_end=3994
  _GETPUBLICDATASETSREQUEST._serialized_start=3996
  _GETPUBLICDATASETSREQUEST._serialized_end=4088
  _GETPUBLICDATASETSRESPONSE._serialized_start=4090
  _GETPUBLICDATASETSRESPONSE._serialized_end=4182
  _GETACCOUNTDATASETSREQUEST._serialized_start=4184
  _GETACCOUNTDATASETSREQUEST._serialized_end=4277
  _GETACCOUNTDATASETSRESPONSE._serialized_start=4279
  _GETACCOUNTDATASETSRESPONSE._serialized_end=4372
  _CHECKDATASETISPUBLICREQUEST._serialized_start=4374
  _CHECKDATASETISPUBLICREQUEST._serialized_end=4422
  _CHECKDATASETISPUBLICRESPONSE._serialized_start=4424
  _CHECKDATASETISPUBLICRESPONSE._serialized_end=4519
  _NEWCLASSREQUEST._serialized_start=4522
  _NEWCLASSREQUEST._serialized_end=4769
  _NEWCLASSREQUEST_NEWCLASSESENTRY._serialized_start=4720
  _NEWCLASSREQUEST_NEWCLASSESENTRY._serialized_end=4769
  _NEWCLASSRESPONSE._serialized_start=4772
  _NEWCLASSRESPONSE._serialized_end=4962
  _NEWCLASSRESPONSE_NEWCLASSESENTRY._serialized_start=4720
  _NEWCLASSRESPONSE_NEWCLASSESENTRY._serialized_end=4769
  _REMOVECLASSREQUEST._serialized_start=4964
  _REMOVECLASSREQUEST._serialized_end=5090
  _REMOVEOPERATIONREQUEST._serialized_start=5093
  _REMOVEOPERATIONREQUEST._serialized_end=5258
  _REMOVEIMPLEMENTATIONREQUEST._serialized_start=5261
  _REMOVEIMPLEMENTATIONREQUEST._serialized_end=5422
  _GETOPERATIONIDREQUEST._serialized_start=5425
  _GETOPERATIONIDREQUEST._serialized_end=5589
  _GETOPERATIONIDRESPONSE._serialized_start=5591
  _GETOPERATIONIDRESPONSE._serialized_end=5683
  _GETPROPERTYIDREQUEST._serialized_start=5686
  _GETPROPERTYIDREQUEST._serialized_end=5836
  _GETPROPERTYIDRESPONSE._serialized_start=5838
  _GETPROPERTYIDRESPONSE._serialized_end=5928
  _GETCLASSIDREQUEST._serialized_start=5930
  _GETCLASSIDREQUEST._serialized_end=6055
  _GETCLASSIDRESPONSE._serialized_start=6057
  _GETCLASSIDRESPONSE._serialized_end=6141
  _GETCLASSINFOREQUEST._serialized_start=6143
  _GETCLASSINFOREQUEST._serialized_end=6270
  _GETCLASSINFORESPONSE._serialized_start=6272
  _GETCLASSINFORESPONSE._serialized_end=6364
  _GETINFOOFCLASSESINNAMESPACEREQUEST._serialized_start=6366
  _GETINFOOFCLASSESINNAMESPACEREQUEST._serialized_end=6489
  _GETINFOOFCLASSESINNAMESPACERESPONSE._serialized_start=6492
  _GETINFOOFCLASSESINNAMESPACERESPONSE._serialized_end=6723
  _GETINFOOFCLASSESINNAMESPACERESPONSE_CLASSESINFOENTRY._serialized_start=6673
  _GETINFOOFCLASSESINNAMESPACERESPONSE_CLASSESINFOENTRY._serialized_end=6723
  _GETIMPORTEDCLASSESINFOINNAMESPACEREQUEST._serialized_start=6726
  _GETIMPORTEDCLASSESINFOINNAMESPACEREQUEST._serialized_end=6855
  _GETIMPORTEDCLASSESINFOINNAMESPACERESPONSE._serialized_start=6858
  _GETIMPORTEDCLASSESINFOINNAMESPACERESPONSE._serialized_end=7113
  _GETIMPORTEDCLASSESINFOINNAMESPACERESPONSE_IMPORTEDCLASSESENTRY._serialized_start=7059
  _GETIMPORTEDCLASSESINFOINNAMESPACERESPONSE_IMPORTEDCLASSESENTRY._serialized_end=7113
  _GETCLASSIDFROMIMPORTREQUEST._serialized_start=7116
  _GETCLASSIDFROMIMPORTREQUEST._serialized_end=7251
  _GETCLASSIDFROMIMPORTRESPONSE._serialized_start=7253
  _GETCLASSIDFROMIMPORTRESPONSE._serialized_end=7347
  _NEWCONTRACTREQUEST._serialized_start=7349
  _NEWCONTRACTREQUEST._serialized_end=7460
  _NEWCONTRACTRESPONSE._serialized_start=7462
  _NEWCONTRACTRESPONSE._serialized_end=7550
  _REGISTERTOPUBLICCONTRACTREQUEST._serialized_start=7552
  _REGISTERTOPUBLICCONTRACTREQUEST._serialized_end=7671
  _REGISTERTOPUBLICCONTRACTOFNAMESPACEREQUEST._serialized_start=7674
  _REGISTERTOPUBLICCONTRACTOFNAMESPACEREQUEST._serialized_end=7805
  _REGISTERTOPUBLICCONTRACTOFNAMESPACERESPONSE._serialized_start=7807
  _REGISTERTOPUBLICCONTRACTOFNAMESPACERESPONSE._serialized_end=7919
  _GETCONTRACTIDSOFAPPLICANTREQUEST._serialized_start=7921
  _GETCONTRACTIDSOFAPPLICANTREQUEST._serialized_end=8023
  _GETCONTRACTIDSOFAPPLICANTRESPONSE._serialized_start=8026
  _GETCONTRACTIDSOFAPPLICANTRESPONSE._serialized_end=8247
  _GETCONTRACTIDSOFAPPLICANTRESPONSE_CONTRACTSENTRY._serialized_start=8199
  _GETCONTRACTIDSOFAPPLICANTRESPONSE_CONTRACTSENTRY._serialized_end=8247
  _GETCONTRACTIDSOFPROVIDERREQUEST._serialized_start=8250
  _GETCONTRACTIDSOFPROVIDERREQUEST._serialized_end=8381
  _GETCONTRACTIDSOFPROVIDERRESPONSE._serialized_start=8384
  _GETCONTRACTIDSOFPROVIDERRESPONSE._serialized_end=8603
  _GETCONTRACTIDSOFPROVIDERRESPONSE_CONTRACTSENTRY._serialized_start=8199
  _GETCONTRACTIDSOFPROVIDERRESPONSE_CONTRACTSENTRY._serialized_end=8247
  _GETCONTRACTSOFAPPLICANTWITHPROVREQUEST._serialized_start=8606
  _GETCONTRACTSOFAPPLICANTWITHPROVREQUEST._serialized_end=8745
  _GETCONTRACTSOFAPPLICANTWITHPROVRESPONSE._serialized_start=8748
  _GETCONTRACTSOFAPPLICANTWITHPROVRESPONSE._serialized_end=8981
  _GETCONTRACTSOFAPPLICANTWITHPROVRESPONSE_CONTRACTSENTRY._serialized_start=8199
  _GETCONTRACTSOFAPPLICANTWITHPROVRESPONSE_CONTRACTSENTRY._serialized_end=8247
  _NEWDATACONTRACTREQUEST._serialized_start=8983
  _NEWDATACONTRACTREQUEST._serialized_end=9099
  _NEWDATACONTRACTRESPONSE._serialized_start=9101
  _NEWDATACONTRACTRESPONSE._serialized_end=9197
  _REGISTERTOPUBLICDATACONTRACTREQUEST._serialized_start=9199
  _REGISTERTOPUBLICDATACONTRACTREQUEST._serialized_end=9326
  _GETDATACONTRACTIDSOFAPPLICANTREQUEST._serialized_start=9328
  _GETDATACONTRACTIDSOFAPPLICANTREQUEST._serialized_end=9434
  _GETDATACONTRACTIDSOFAPPLICANTRESPONSE._serialized_start=9437
  _GETDATACONTRACTIDSOFAPPLICANTRESPONSE._serialized_end=9678
  _GETDATACONTRACTIDSOFAPPLICANTRESPONSE_DATACONTRACTSENTRY._serialized_start=9626
  _GETDATACONTRACTIDSOFAPPLICANTRESPONSE_DATACONTRACTSENTRY._serialized_end=9678
  _GETDATACONTRACTIDSOFPROVIDERREQUEST._serialized_start=9681
  _GETDATACONTRACTIDSOFPROVIDERREQUEST._serialized_end=9814
  _GETDATACONTRACTIDSOFPROVIDERRESPONSE._serialized_start=9817
  _GETDATACONTRACTIDSOFPROVIDERRESPONSE._serialized_end=10056
  _GETDATACONTRACTIDSOFPROVIDERRESPONSE_DATACONTRACTSENTRY._serialized_start=9626
  _GETDATACONTRACTIDSOFPROVIDERRESPONSE_DATACONTRACTSENTRY._serialized_end=9678
  _GETDATACONTRACTINFOOFAPPLICANTWITHPROVREQUEST._serialized_start=10059
  _GETDATACONTRACTINFOOFAPPLICANTWITHPROVREQUEST._serialized_end=10203
  _GETDATACONTRACTINFOOFAPPLICANTWITHPROVRESPONSE._serialized_start=10205
  _GETDATACONTRACTINFOOFAPPLICANTWITHPROVRESPONSE._serialized_end=10326
  _NEWINTERFACEREQUEST._serialized_start=10328
  _NEWINTERFACEREQUEST._serialized_end=10440
  _NEWINTERFACERESPONSE._serialized_start=10442
  _NEWINTERFACERESPONSE._serialized_end=10532
  _GETINTERFACEINFOREQUEST._serialized_start=10534
  _GETINTERFACEINFOREQUEST._serialized_end=10648
  _GETINTERFACEINFORESPONSE._serialized_start=10650
  _GETINTERFACEINFORESPONSE._serialized_end=10746
  _REMOVEINTERFACEREQUEST._serialized_start=10749
  _REMOVEINTERFACEREQUEST._serialized_end=10883
  _GETSTORAGELOCATIONINFOREQUEST._serialized_start=10885
  _GETSTORAGELOCATIONINFOREQUEST._serialized_end=10964
  _GETSTORAGELOCATIONINFORESPONSE._serialized_start=10967
  _GETSTORAGELOCATIONINFORESPONSE._serialized_end=11111
  _GETEXECUTIONENVIRONMENTINFOREQUEST._serialized_start=11113
  _GETEXECUTIONENVIRONMENTINFOREQUEST._serialized_end=11189
  _GETEXECUTIONENVIRONMENTINFORESPONSE._serialized_start=11192
  _GETEXECUTIONENVIRONMENTINFORESPONSE._serialized_end=11351
  _GETDATACLAYIDRESPONSE._serialized_start=11353
  _GETDATACLAYIDRESPONSE._serialized_end=11443
  _REGISTEREXTERNALDATACLAYREQUEST._serialized_start=11445
  _REGISTEREXTERNALDATACLAYREQUEST._serialized_end=11510
  _REGISTEREXTERNALDATACLAYOVERRIDEAUTHORITYREQUEST._serialized_start=11513
  _REGISTEREXTERNALDATACLAYOVERRIDEAUTHORITYREQUEST._serialized_end=11690
  _REGISTEREXTERNALDATACLAYRESPONSE._serialized_start=11692
  _REGISTEREXTERNALDATACLAYRESPONSE._serialized_end=11796
  _NOTIFYREGISTRATIONOFEXTERNALDATACLAYREQUEST._serialized_start=11798
  _NOTIFYREGISTRATIONOFEXTERNALDATACLAYREQUEST._serialized_end=11898
  _NOTIFYREGISTRATIONOFEXTERNALDATACLAYRESPONSE._serialized_start=11900
  _NOTIFYREGISTRATIONOFEXTERNALDATACLAYRESPONSE._serialized_end=12016
  _GETEXTERNALDATACLAYIDREQUEST._serialized_start=12018
  _GETEXTERNALDATACLAYIDREQUEST._serialized_end=12076
  _GETEXTERNALDATACLAYIDRESPONSE._serialized_start=12078
  _GETEXTERNALDATACLAYIDRESPONSE._serialized_end=12179
  _GETEXTDATACLAYINFOREQUEST._serialized_start=12181
  _GETEXTDATACLAYINFOREQUEST._serialized_end=12231
  _GETEXTDATACLAYINFORESPONSE._serialized_start=12234
  _GETEXTDATACLAYINFORESPONSE._serialized_end=12367
  _REGISTEROBJECTFORGCREQUEST._serialized_start=12369
  _REGISTEROBJECTFORGCREQUEST._serialized_end=12466
  _REGISTEROBJECTSREQUEST._serialized_start=12469
  _REGISTEROBJECTSREQUEST._serialized_end=12599
  _REGISTEROBJECTSRESPONSE._serialized_start=12601
  _REGISTEROBJECTSRESPONSE._serialized_end=12692
  _GETALLEXECUTIONENVIRONMENTSINFOREQUEST._serialized_start=12694
  _GETALLEXECUTIONENVIRONMENTSINFOREQUEST._serialized_end=12819
  _GETALLEXECUTIONENVIRONMENTSINFORESPONSE._serialized_start=12822
  _GETALLEXECUTIONENVIRONMENTSINFORESPONSE._serialized_end=13093
  _GETALLEXECUTIONENVIRONMENTSINFORESPONSE_EXECENVSENTRY._serialized_start=13005
  _GETALLEXECUTIONENVIRONMENTSINFORESPONSE_EXECENVSENTRY._serialized_end=13093
  _GETOBJECTINFOREQUEST._serialized_start=13095
  _GETOBJECTINFOREQUEST._serialized_end=13154
  _GETOBJECTINFORESPONSE._serialized_start=13156
  _GETOBJECTINFORESPONSE._serialized_end=13264
  _GETOBJECTFROMALIASREQUEST._serialized_start=13266
  _GETOBJECTFROMALIASREQUEST._serialized_end=13327
  _GETOBJECTFROMALIASRESPONSE._serialized_start=13329
  _GETOBJECTFROMALIASRESPONSE._serialized_end=13453
  _ADDALIASREQUEST._serialized_start=13455
  _ADDALIASREQUEST._serialized_end=13516
  _DELETEALIASREQUEST._serialized_start=13518
  _DELETEALIASREQUEST._serialized_end=13572
  _DELETEALIASRESPONSE._serialized_start=13574
  _DELETEALIASRESPONSE._serialized_end=13660
  _GETOBJECTSMETADATAINFOOFCLASSFORNMREQUEST._serialized_start=13662
  _GETOBJECTSMETADATAINFOOFCLASSFORNMREQUEST._serialized_end=13722
  _GETOBJECTSMETADATAINFOOFCLASSFORNMRESPONSE._serialized_start=13725
  _GETOBJECTSMETADATAINFOOFCLASSFORNMRESPONSE._serialized_end=13993
  _GETOBJECTSMETADATAINFOOFCLASSFORNMRESPONSE_MDATAINFOENTRY._serialized_start=13916
  _GETOBJECTSMETADATAINFOOFCLASSFORNMRESPONSE_MDATAINFOENTRY._serialized_end=13993
  _SETDATASETIDREQUEST._serialized_start=13995
  _SETDATASETIDREQUEST._serialized_end=14072
  _SETDATASETIDFROMGARBAGECOLLECTORREQUEST._serialized_start=14074
  _SETDATASETIDFROMGARBAGECOLLECTORREQUEST._serialized_end=14152
  _MOVEOBJECTREQUEST._serialized_start=14154
  _MOVEOBJECTREQUEST._serialized_end=14274
  _MOVEOBJECTRESPONSE._serialized_start=14276
  _MOVEOBJECTRESPONSE._serialized_end=14362
  _SETOBJECTREADONLYREQUEST._serialized_start=14364
  _SETOBJECTREADONLYREQUEST._serialized_end=14427
  _SETOBJECTREADWRITEREQUEST._serialized_start=14429
  _SETOBJECTREADWRITEREQUEST._serialized_end=14493
  _GETMETADATABYOIDREQUEST._serialized_start=14495
  _GETMETADATABYOIDREQUEST._serialized_end=14557
  _GETMETADATABYOIDRESPONSE._serialized_start=14559
  _GETMETADATABYOIDRESPONSE._serialized_end=14677
  _GETMETADATABYOIDFORDSREQUEST._serialized_start=14679
  _GETMETADATABYOIDFORDSREQUEST._serialized_end=14727
  _GETMETADATABYOIDFORDSRESPONSE._serialized_start=14729
  _GETMETADATABYOIDFORDSRESPONSE._serialized_end=14852
  _EXECUTEIMPLEMENTATIONREQUEST._serialized_start=14855
  _EXECUTEIMPLEMENTATIONREQUEST._serialized_end=15071
  _EXECUTEIMPLEMENTATIONRESPONSE._serialized_start=15074
  _EXECUTEIMPLEMENTATIONRESPONSE._serialized_end=15210
  _EXECUTEMETHODONTARGETREQUEST._serialized_start=15213
  _EXECUTEMETHODONTARGETREQUEST._serialized_end=15401
  _EXECUTEMETHODONTARGETRESPONSE._serialized_start=15404
  _EXECUTEMETHODONTARGETRESPONSE._serialized_end=15540
  _SYNCHRONIZEFEDERATEDOBJECTREQUEST._serialized_start=15543
  _SYNCHRONIZEFEDERATEDOBJECTREQUEST._serialized_end=15727
  _GETSTUBSREQUEST._serialized_start=15730
  _GETSTUBSREQUEST._serialized_end=15884
  _GETSTUBSRESPONSE._serialized_start=15887
  _GETSTUBSRESPONSE._serialized_end=16062
  _GETSTUBSRESPONSE_STUBSENTRY._serialized_start=16018
  _GETSTUBSRESPONSE_STUBSENTRY._serialized_end=16062
  _GETBABELSTUBSREQUEST._serialized_start=16064
  _GETBABELSTUBSREQUEST._serialized_end=16174
  _GETBABELSTUBSRESPONSE._serialized_start=16176
  _GETBABELSTUBSRESPONSE._serialized_end=16264
  _GETCLASSNAMEFORDSREQUEST._serialized_start=16266
  _GETCLASSNAMEFORDSREQUEST._serialized_end=16309
  _GETCLASSNAMEFORDSRESPONSE._serialized_start=16311
  _GETCLASSNAMEFORDSRESPONSE._serialized_end=16404
  _GETCLASSNAMEANDNAMESPACEFORDSREQUEST._serialized_start=16406
  _GETCLASSNAMEANDNAMESPACEFORDSREQUEST._serialized_end=16461
  _GETCLASSNAMEANDNAMESPACEFORDSRESPONSE._serialized_start=16463
  _GETCLASSNAMEANDNAMESPACEFORDSRESPONSE._serialized_end=16587
  _REGISTERECAREQUEST._serialized_start=16589
  _REGISTERECAREQUEST._serialized_end=16698
  _ADVISEEVENTREQUEST._serialized_start=16700
  _ADVISEEVENTREQUEST._serialized_end=16739
  _GETCONTRACTIDOFDATACLAYPROVIDERREQUEST._serialized_start=16741
  _GETCONTRACTIDOFDATACLAYPROVIDERREQUEST._serialized_end=16857
  _GETCONTRACTIDOFDATACLAYPROVIDERRESPONSE._serialized_start=16859
  _GETCONTRACTIDOFDATACLAYPROVIDERRESPONSE._serialized_end=16967
  _ACTIVATETRACINGREQUEST._serialized_start=16969
  _ACTIVATETRACINGREQUEST._serialized_end=17009
  _CLOSESESSIONREQUEST._serialized_start=17011
  _CLOSESESSIONREQUEST._serialized_end=17051
  _UNREGISTEROBJECTSREQUEST._serialized_start=17053
  _UNREGISTEROBJECTSREQUEST._serialized_end=17108
  _ISPREFETCHINGENABLEDRESPONSE._serialized_start=17110
  _ISPREFETCHINGENABLEDRESPONSE._serialized_end=17204
  _OBJECTEXISTSINDATACLAYREQUEST._serialized_start=17206
  _OBJECTEXISTSINDATACLAYREQUEST._serialized_end=17255
  _OBJECTEXISTSINDATACLAYRESPONSE._serialized_start=17257
  _OBJECTEXISTSINDATACLAYRESPONSE._serialized_end=17352
  _GETCLASSESINNAMESPACEREQUEST._serialized_start=17354
  _GETCLASSESINNAMESPACEREQUEST._serialized_end=17407
  _GETCLASSESINNAMESPACERESPONSE._serialized_start=17409
  _GETCLASSESINNAMESPACERESPONSE._serialized_end=17533
  _IMPORTMODELSFROMEXTERNALDATACLAYREQUEST._serialized_start=17535
  _IMPORTMODELSFROMEXTERNALDATACLAYREQUEST._serialized_end=17619
  _GETSTORAGELOCATIONIDREQUEST._serialized_start=17621
  _GETSTORAGELOCATIONIDREQUEST._serialized_end=17666
  _GETSTORAGELOCATIONIDRESPONSE._serialized_start=17668
  _GETSTORAGELOCATIONIDRESPONSE._serialized_end=17772
  _NOTIFYEXECUTIONENVIRONMENTSHUTDOWNREQUEST._serialized_start=17774
  _NOTIFYEXECUTIONENVIRONMENTSHUTDOWNREQUEST._serialized_end=17849
  _NOTIFYSTORAGELOCATIONSHUTDOWNREQUEST._serialized_start=17851
  _NOTIFYSTORAGELOCATIONSHUTDOWNREQUEST._serialized_end=17916
  _EXISTSACTIVEENVIRONMENTSFORSLREQUEST._serialized_start=17918
  _EXISTSACTIVEENVIRONMENTSFORSLREQUEST._serialized_end=17983
  _EXISTSACTIVEENVIRONMENTSFORSLRESPONSE._serialized_start=17985
  _EXISTSACTIVEENVIRONMENTSFORSLRESPONSE._serialized_end=18087
  _METADATAINFO._serialized_start=18090
  _METADATAINFO._serialized_end=18235
# @@protoc_insertion_point(module_scope)
